"""
Material Icons constants for IDE autocompletion.

This file is auto-generated by generate_icons.py script.
DO NOT EDIT MANUALLY - run the script to update.

Generated from Google Material Design Icons.
Total icons: 2234
"""

from typing import Dict, Final


class Icons:
    """
    Material Design Icons constants for IDE autocompletion.
    
    Usage:
        from django_cfg.modules.django_unfold.icons import Icons
        
        # IDE will provide autocompletion
        icon = Icons.DASHBOARD
        icon = Icons.SETTINGS
        icon = Icons.PEOPLE
    """

    _10K: Final[str] = "10k"
    _10MP: Final[str] = "10mp"
    _11MP: Final[str] = "11mp"
    _123: Final[str] = "123"
    _12MP: Final[str] = "12mp"
    _13MP: Final[str] = "13mp"
    _14MP: Final[str] = "14mp"
    _15MP: Final[str] = "15mp"
    _16MP: Final[str] = "16mp"
    _17MP: Final[str] = "17mp"
    _18_UP_RATING: Final[str] = "18_up_rating"
    _18MP: Final[str] = "18mp"
    _19MP: Final[str] = "19mp"
    _1K: Final[str] = "1k"
    _1K_PLUS: Final[str] = "1k_plus"
    _1X_MOBILEDATA: Final[str] = "1x_mobiledata"
    _20MP: Final[str] = "20mp"
    _21MP: Final[str] = "21mp"
    _22MP: Final[str] = "22mp"
    _23MP: Final[str] = "23mp"
    _24MP: Final[str] = "24mp"
    _2K: Final[str] = "2k"
    _2K_PLUS: Final[str] = "2k_plus"
    _2MP: Final[str] = "2mp"
    _30FPS: Final[str] = "30fps"
    _30FPS_SELECT: Final[str] = "30fps_select"
    _360: Final[str] = "360"
    _3D_ROTATION: Final[str] = "3d_rotation"
    _3G_MOBILEDATA: Final[str] = "3g_mobiledata"
    _3K: Final[str] = "3k"
    _3K_PLUS: Final[str] = "3k_plus"
    _3MP: Final[str] = "3mp"
    _3P: Final[str] = "3p"
    _4G_MOBILEDATA: Final[str] = "4g_mobiledata"
    _4G_PLUS_MOBILEDATA: Final[str] = "4g_plus_mobiledata"
    _4K: Final[str] = "4k"
    _4K_PLUS: Final[str] = "4k_plus"
    _4MP: Final[str] = "4mp"
    _5G: Final[str] = "5g"
    _5K: Final[str] = "5k"
    _5K_PLUS: Final[str] = "5k_plus"
    _5MP: Final[str] = "5mp"
    _60FPS: Final[str] = "60fps"
    _60FPS_SELECT: Final[str] = "60fps_select"
    _6_FT_APART: Final[str] = "6_ft_apart"
    _6K: Final[str] = "6k"
    _6K_PLUS: Final[str] = "6k_plus"
    _6MP: Final[str] = "6mp"
    _7K: Final[str] = "7k"
    _7K_PLUS: Final[str] = "7k_plus"
    _7MP: Final[str] = "7mp"
    _8K: Final[str] = "8k"
    _8K_PLUS: Final[str] = "8k_plus"
    _8MP: Final[str] = "8mp"
    _9K: Final[str] = "9k"
    _9K_PLUS: Final[str] = "9k_plus"
    _9MP: Final[str] = "9mp"
    ABC: Final[str] = "abc"
    AC_UNIT: Final[str] = "ac_unit"
    ACCESS_ALARM: Final[str] = "access_alarm"
    ACCESS_ALARMS: Final[str] = "access_alarms"
    ACCESS_TIME: Final[str] = "access_time"
    ACCESS_TIME_FILLED: Final[str] = "access_time_filled"
    ACCESSIBILITY: Final[str] = "accessibility"
    ACCESSIBILITY_NEW: Final[str] = "accessibility_new"
    ACCESSIBLE: Final[str] = "accessible"
    ACCESSIBLE_FORWARD: Final[str] = "accessible_forward"
    ACCOUNT_BALANCE: Final[str] = "account_balance"
    ACCOUNT_BALANCE_WALLET: Final[str] = "account_balance_wallet"
    ACCOUNT_BOX: Final[str] = "account_box"
    ACCOUNT_CIRCLE: Final[str] = "account_circle"
    ACCOUNT_TREE: Final[str] = "account_tree"
    AD_UNITS: Final[str] = "ad_units"
    ADB: Final[str] = "adb"
    ADD: Final[str] = "add"
    ADD_A_PHOTO: Final[str] = "add_a_photo"
    ADD_ALARM: Final[str] = "add_alarm"
    ADD_ALERT: Final[str] = "add_alert"
    ADD_BOX: Final[str] = "add_box"
    ADD_BUSINESS: Final[str] = "add_business"
    ADD_CALL: Final[str] = "add_call"
    ADD_CARD: Final[str] = "add_card"
    ADD_CHART: Final[str] = "add_chart"
    ADD_CIRCLE: Final[str] = "add_circle"
    ADD_CIRCLE_OUTLINE: Final[str] = "add_circle_outline"
    ADD_COMMENT: Final[str] = "add_comment"
    ADD_HOME: Final[str] = "add_home"
    ADD_HOME_WORK: Final[str] = "add_home_work"
    ADD_IC_CALL: Final[str] = "add_ic_call"
    ADD_LINK: Final[str] = "add_link"
    ADD_LOCATION: Final[str] = "add_location"
    ADD_LOCATION_ALT: Final[str] = "add_location_alt"
    ADD_MODERATOR: Final[str] = "add_moderator"
    ADD_PHOTO_ALTERNATE: Final[str] = "add_photo_alternate"
    ADD_REACTION: Final[str] = "add_reaction"
    ADD_ROAD: Final[str] = "add_road"
    ADD_SHOPPING_CART: Final[str] = "add_shopping_cart"
    ADD_TASK: Final[str] = "add_task"
    ADD_TO_DRIVE: Final[str] = "add_to_drive"
    ADD_TO_HOME_SCREEN: Final[str] = "add_to_home_screen"
    ADD_TO_PHOTOS: Final[str] = "add_to_photos"
    ADD_TO_QUEUE: Final[str] = "add_to_queue"
    ADDCHART: Final[str] = "addchart"
    ADF_SCANNER: Final[str] = "adf_scanner"
    ADJUST: Final[str] = "adjust"
    ADMIN_PANEL_SETTINGS: Final[str] = "admin_panel_settings"
    ADOBE: Final[str] = "adobe"
    ADS_CLICK: Final[str] = "ads_click"
    AGRICULTURE: Final[str] = "agriculture"
    AIR: Final[str] = "air"
    AIRLINE_SEAT_FLAT: Final[str] = "airline_seat_flat"
    AIRLINE_SEAT_FLAT_ANGLED: Final[str] = "airline_seat_flat_angled"
    AIRLINE_SEAT_INDIVIDUAL_SUITE: Final[str] = "airline_seat_individual_suite"
    AIRLINE_SEAT_LEGROOM_EXTRA: Final[str] = "airline_seat_legroom_extra"
    AIRLINE_SEAT_LEGROOM_NORMAL: Final[str] = "airline_seat_legroom_normal"
    AIRLINE_SEAT_LEGROOM_REDUCED: Final[str] = "airline_seat_legroom_reduced"
    AIRLINE_SEAT_RECLINE_EXTRA: Final[str] = "airline_seat_recline_extra"
    AIRLINE_SEAT_RECLINE_NORMAL: Final[str] = "airline_seat_recline_normal"
    AIRLINE_STOPS: Final[str] = "airline_stops"
    AIRLINES: Final[str] = "airlines"
    AIRPLANE_TICKET: Final[str] = "airplane_ticket"
    AIRPLANEMODE_ACTIVE: Final[str] = "airplanemode_active"
    AIRPLANEMODE_INACTIVE: Final[str] = "airplanemode_inactive"
    AIRPLANEMODE_OFF: Final[str] = "airplanemode_off"
    AIRPLANEMODE_ON: Final[str] = "airplanemode_on"
    AIRPLAY: Final[str] = "airplay"
    AIRPORT_SHUTTLE: Final[str] = "airport_shuttle"
    ALARM: Final[str] = "alarm"
    ALARM_ADD: Final[str] = "alarm_add"
    ALARM_OFF: Final[str] = "alarm_off"
    ALARM_ON: Final[str] = "alarm_on"
    ALBUM: Final[str] = "album"
    ALIGN_HORIZONTAL_CENTER: Final[str] = "align_horizontal_center"
    ALIGN_HORIZONTAL_LEFT: Final[str] = "align_horizontal_left"
    ALIGN_HORIZONTAL_RIGHT: Final[str] = "align_horizontal_right"
    ALIGN_VERTICAL_BOTTOM: Final[str] = "align_vertical_bottom"
    ALIGN_VERTICAL_CENTER: Final[str] = "align_vertical_center"
    ALIGN_VERTICAL_TOP: Final[str] = "align_vertical_top"
    ALL_INBOX: Final[str] = "all_inbox"
    ALL_INCLUSIVE: Final[str] = "all_inclusive"
    ALL_OUT: Final[str] = "all_out"
    ALT_ROUTE: Final[str] = "alt_route"
    ALTERNATE_EMAIL: Final[str] = "alternate_email"
    AMP_STORIES: Final[str] = "amp_stories"
    ANALYTICS: Final[str] = "analytics"
    ANCHOR: Final[str] = "anchor"
    ANDROID: Final[str] = "android"
    ANIMATION: Final[str] = "animation"
    ANNOUNCEMENT: Final[str] = "announcement"
    AOD: Final[str] = "aod"
    APARTMENT: Final[str] = "apartment"
    API: Final[str] = "api"
    APP_BLOCKING: Final[str] = "app_blocking"
    APP_REGISTRATION: Final[str] = "app_registration"
    APP_SETTINGS_ALT: Final[str] = "app_settings_alt"
    APP_SHORTCUT: Final[str] = "app_shortcut"
    APPLE: Final[str] = "apple"
    APPROVAL: Final[str] = "approval"
    APPS: Final[str] = "apps"
    APPS_OUTAGE: Final[str] = "apps_outage"
    ARCHITECTURE: Final[str] = "architecture"
    ARCHIVE: Final[str] = "archive"
    AREA_CHART: Final[str] = "area_chart"
    ARROW_BACK: Final[str] = "arrow_back"
    ARROW_BACK_IOS: Final[str] = "arrow_back_ios"
    ARROW_BACK_IOS_NEW: Final[str] = "arrow_back_ios_new"
    ARROW_CIRCLE_DOWN: Final[str] = "arrow_circle_down"
    ARROW_CIRCLE_LEFT: Final[str] = "arrow_circle_left"
    ARROW_CIRCLE_RIGHT: Final[str] = "arrow_circle_right"
    ARROW_CIRCLE_UP: Final[str] = "arrow_circle_up"
    ARROW_DOWNWARD: Final[str] = "arrow_downward"
    ARROW_DROP_DOWN: Final[str] = "arrow_drop_down"
    ARROW_DROP_DOWN_CIRCLE: Final[str] = "arrow_drop_down_circle"
    ARROW_DROP_UP: Final[str] = "arrow_drop_up"
    ARROW_FORWARD: Final[str] = "arrow_forward"
    ARROW_FORWARD_IOS: Final[str] = "arrow_forward_ios"
    ARROW_LEFT: Final[str] = "arrow_left"
    ARROW_OUTWARD: Final[str] = "arrow_outward"
    ARROW_RIGHT: Final[str] = "arrow_right"
    ARROW_RIGHT_ALT: Final[str] = "arrow_right_alt"
    ARROW_UPWARD: Final[str] = "arrow_upward"
    ART_TRACK: Final[str] = "art_track"
    ARTICLE: Final[str] = "article"
    ASPECT_RATIO: Final[str] = "aspect_ratio"
    ASSESSMENT: Final[str] = "assessment"
    ASSIGNMENT: Final[str] = "assignment"
    ASSIGNMENT_ADD: Final[str] = "assignment_add"
    ASSIGNMENT_IND: Final[str] = "assignment_ind"
    ASSIGNMENT_LATE: Final[str] = "assignment_late"
    ASSIGNMENT_RETURN: Final[str] = "assignment_return"
    ASSIGNMENT_RETURNED: Final[str] = "assignment_returned"
    ASSIGNMENT_TURNED_IN: Final[str] = "assignment_turned_in"
    ASSIST_WALKER: Final[str] = "assist_walker"
    ASSISTANT: Final[str] = "assistant"
    ASSISTANT_DIRECTION: Final[str] = "assistant_direction"
    ASSISTANT_NAVIGATION: Final[str] = "assistant_navigation"
    ASSISTANT_PHOTO: Final[str] = "assistant_photo"
    ASSURED_WORKLOAD: Final[str] = "assured_workload"
    ATM: Final[str] = "atm"
    ATTACH_EMAIL: Final[str] = "attach_email"
    ATTACH_FILE: Final[str] = "attach_file"
    ATTACH_MONEY: Final[str] = "attach_money"
    ATTACHMENT: Final[str] = "attachment"
    ATTRACTIONS: Final[str] = "attractions"
    ATTRIBUTION: Final[str] = "attribution"
    AUDIO_FILE: Final[str] = "audio_file"
    AUDIOTRACK: Final[str] = "audiotrack"
    AUTO_AWESOME: Final[str] = "auto_awesome"
    AUTO_AWESOME_MOSAIC: Final[str] = "auto_awesome_mosaic"
    AUTO_AWESOME_MOTION: Final[str] = "auto_awesome_motion"
    AUTO_DELETE: Final[str] = "auto_delete"
    AUTO_FIX_HIGH: Final[str] = "auto_fix_high"
    AUTO_FIX_NORMAL: Final[str] = "auto_fix_normal"
    AUTO_FIX_OFF: Final[str] = "auto_fix_off"
    AUTO_GRAPH: Final[str] = "auto_graph"
    AUTO_MODE: Final[str] = "auto_mode"
    AUTO_STORIES: Final[str] = "auto_stories"
    AUTOFPS_SELECT: Final[str] = "autofps_select"
    AUTORENEW: Final[str] = "autorenew"
    AV_TIMER: Final[str] = "av_timer"
    BABY_CHANGING_STATION: Final[str] = "baby_changing_station"
    BACK_HAND: Final[str] = "back_hand"
    BACKPACK: Final[str] = "backpack"
    BACKSPACE: Final[str] = "backspace"
    BACKUP: Final[str] = "backup"
    BACKUP_TABLE: Final[str] = "backup_table"
    BADGE: Final[str] = "badge"
    BAKERY_DINING: Final[str] = "bakery_dining"
    BALANCE: Final[str] = "balance"
    BALCONY: Final[str] = "balcony"
    BALLOT: Final[str] = "ballot"
    BAR_CHART: Final[str] = "bar_chart"
    BARCODE_READER: Final[str] = "barcode_reader"
    BATCH_PREDICTION: Final[str] = "batch_prediction"
    BATHROOM: Final[str] = "bathroom"
    BATHTUB: Final[str] = "bathtub"
    BATTERY_0_BAR: Final[str] = "battery_0_bar"
    BATTERY_1_BAR: Final[str] = "battery_1_bar"
    BATTERY_2_BAR: Final[str] = "battery_2_bar"
    BATTERY_3_BAR: Final[str] = "battery_3_bar"
    BATTERY_4_BAR: Final[str] = "battery_4_bar"
    BATTERY_5_BAR: Final[str] = "battery_5_bar"
    BATTERY_6_BAR: Final[str] = "battery_6_bar"
    BATTERY_ALERT: Final[str] = "battery_alert"
    BATTERY_CHARGING_FULL: Final[str] = "battery_charging_full"
    BATTERY_FULL: Final[str] = "battery_full"
    BATTERY_SAVER: Final[str] = "battery_saver"
    BATTERY_STD: Final[str] = "battery_std"
    BATTERY_UNKNOWN: Final[str] = "battery_unknown"
    BEACH_ACCESS: Final[str] = "beach_access"
    BED: Final[str] = "bed"
    BEDROOM_BABY: Final[str] = "bedroom_baby"
    BEDROOM_CHILD: Final[str] = "bedroom_child"
    BEDROOM_PARENT: Final[str] = "bedroom_parent"
    BEDTIME: Final[str] = "bedtime"
    BEDTIME_OFF: Final[str] = "bedtime_off"
    BEENHERE: Final[str] = "beenhere"
    BENTO: Final[str] = "bento"
    BIKE_SCOOTER: Final[str] = "bike_scooter"
    BIOTECH: Final[str] = "biotech"
    BLENDER: Final[str] = "blender"
    BLIND: Final[str] = "blind"
    BLINDS: Final[str] = "blinds"
    BLINDS_CLOSED: Final[str] = "blinds_closed"
    BLOCK: Final[str] = "block"
    BLOCK_FLIPPED: Final[str] = "block_flipped"
    BLOODTYPE: Final[str] = "bloodtype"
    BLUETOOTH: Final[str] = "bluetooth"
    BLUETOOTH_AUDIO: Final[str] = "bluetooth_audio"
    BLUETOOTH_CONNECTED: Final[str] = "bluetooth_connected"
    BLUETOOTH_DISABLED: Final[str] = "bluetooth_disabled"
    BLUETOOTH_DRIVE: Final[str] = "bluetooth_drive"
    BLUETOOTH_SEARCHING: Final[str] = "bluetooth_searching"
    BLUR_CIRCULAR: Final[str] = "blur_circular"
    BLUR_LINEAR: Final[str] = "blur_linear"
    BLUR_OFF: Final[str] = "blur_off"
    BLUR_ON: Final[str] = "blur_on"
    BOLT: Final[str] = "bolt"
    BOOK: Final[str] = "book"
    BOOK_ONLINE: Final[str] = "book_online"
    BOOKMARK: Final[str] = "bookmark"
    BOOKMARK_ADD: Final[str] = "bookmark_add"
    BOOKMARK_ADDED: Final[str] = "bookmark_added"
    BOOKMARK_BORDER: Final[str] = "bookmark_border"
    BOOKMARK_OUTLINE: Final[str] = "bookmark_outline"
    BOOKMARK_REMOVE: Final[str] = "bookmark_remove"
    BOOKMARKS: Final[str] = "bookmarks"
    BORDER_ALL: Final[str] = "border_all"
    BORDER_BOTTOM: Final[str] = "border_bottom"
    BORDER_CLEAR: Final[str] = "border_clear"
    BORDER_COLOR: Final[str] = "border_color"
    BORDER_HORIZONTAL: Final[str] = "border_horizontal"
    BORDER_INNER: Final[str] = "border_inner"
    BORDER_LEFT: Final[str] = "border_left"
    BORDER_OUTER: Final[str] = "border_outer"
    BORDER_RIGHT: Final[str] = "border_right"
    BORDER_STYLE: Final[str] = "border_style"
    BORDER_TOP: Final[str] = "border_top"
    BORDER_VERTICAL: Final[str] = "border_vertical"
    BOY: Final[str] = "boy"
    BRANDING_WATERMARK: Final[str] = "branding_watermark"
    BREAKFAST_DINING: Final[str] = "breakfast_dining"
    BRIGHTNESS_1: Final[str] = "brightness_1"
    BRIGHTNESS_2: Final[str] = "brightness_2"
    BRIGHTNESS_3: Final[str] = "brightness_3"
    BRIGHTNESS_4: Final[str] = "brightness_4"
    BRIGHTNESS_5: Final[str] = "brightness_5"
    BRIGHTNESS_6: Final[str] = "brightness_6"
    BRIGHTNESS_7: Final[str] = "brightness_7"
    BRIGHTNESS_AUTO: Final[str] = "brightness_auto"
    BRIGHTNESS_HIGH: Final[str] = "brightness_high"
    BRIGHTNESS_LOW: Final[str] = "brightness_low"
    BRIGHTNESS_MEDIUM: Final[str] = "brightness_medium"
    BROADCAST_ON_HOME: Final[str] = "broadcast_on_home"
    BROADCAST_ON_PERSONAL: Final[str] = "broadcast_on_personal"
    BROKEN_IMAGE: Final[str] = "broken_image"
    BROWSE_GALLERY: Final[str] = "browse_gallery"
    BROWSER_NOT_SUPPORTED: Final[str] = "browser_not_supported"
    BROWSER_UPDATED: Final[str] = "browser_updated"
    BRUNCH_DINING: Final[str] = "brunch_dining"
    BRUSH: Final[str] = "brush"
    BUBBLE_CHART: Final[str] = "bubble_chart"
    BUG_REPORT: Final[str] = "bug_report"
    BUILD: Final[str] = "build"
    BUILD_CIRCLE: Final[str] = "build_circle"
    BUNGALOW: Final[str] = "bungalow"
    BURST_MODE: Final[str] = "burst_mode"
    BUS_ALERT: Final[str] = "bus_alert"
    BUSINESS: Final[str] = "business"
    BUSINESS_CENTER: Final[str] = "business_center"
    CABIN: Final[str] = "cabin"
    CABLE: Final[str] = "cable"
    CACHED: Final[str] = "cached"
    CAKE: Final[str] = "cake"
    CALCULATE: Final[str] = "calculate"
    CALENDAR_MONTH: Final[str] = "calendar_month"
    CALENDAR_TODAY: Final[str] = "calendar_today"
    CALENDAR_VIEW_DAY: Final[str] = "calendar_view_day"
    CALENDAR_VIEW_MONTH: Final[str] = "calendar_view_month"
    CALENDAR_VIEW_WEEK: Final[str] = "calendar_view_week"
    CALL: Final[str] = "call"
    CALL_END: Final[str] = "call_end"
    CALL_MADE: Final[str] = "call_made"
    CALL_MERGE: Final[str] = "call_merge"
    CALL_MISSED: Final[str] = "call_missed"
    CALL_MISSED_OUTGOING: Final[str] = "call_missed_outgoing"
    CALL_RECEIVED: Final[str] = "call_received"
    CALL_SPLIT: Final[str] = "call_split"
    CALL_TO_ACTION: Final[str] = "call_to_action"
    CAMERA: Final[str] = "camera"
    CAMERA_ALT: Final[str] = "camera_alt"
    CAMERA_ENHANCE: Final[str] = "camera_enhance"
    CAMERA_FRONT: Final[str] = "camera_front"
    CAMERA_INDOOR: Final[str] = "camera_indoor"
    CAMERA_OUTDOOR: Final[str] = "camera_outdoor"
    CAMERA_REAR: Final[str] = "camera_rear"
    CAMERA_ROLL: Final[str] = "camera_roll"
    CAMERASWITCH: Final[str] = "cameraswitch"
    CAMPAIGN: Final[str] = "campaign"
    CANCEL: Final[str] = "cancel"
    CANCEL_PRESENTATION: Final[str] = "cancel_presentation"
    CANCEL_SCHEDULE_SEND: Final[str] = "cancel_schedule_send"
    CANDLESTICK_CHART: Final[str] = "candlestick_chart"
    CAR_CRASH: Final[str] = "car_crash"
    CAR_RENTAL: Final[str] = "car_rental"
    CAR_REPAIR: Final[str] = "car_repair"
    CARD_GIFTCARD: Final[str] = "card_giftcard"
    CARD_MEMBERSHIP: Final[str] = "card_membership"
    CARD_TRAVEL: Final[str] = "card_travel"
    CARPENTER: Final[str] = "carpenter"
    CASES: Final[str] = "cases"
    CASINO: Final[str] = "casino"
    CAST: Final[str] = "cast"
    CAST_CONNECTED: Final[str] = "cast_connected"
    CAST_FOR_EDUCATION: Final[str] = "cast_for_education"
    CASTLE: Final[str] = "castle"
    CATCHING_POKEMON: Final[str] = "catching_pokemon"
    CATEGORY: Final[str] = "category"
    CELEBRATION: Final[str] = "celebration"
    CELL_TOWER: Final[str] = "cell_tower"
    CELL_WIFI: Final[str] = "cell_wifi"
    CENTER_FOCUS_STRONG: Final[str] = "center_focus_strong"
    CENTER_FOCUS_WEAK: Final[str] = "center_focus_weak"
    CHAIR: Final[str] = "chair"
    CHAIR_ALT: Final[str] = "chair_alt"
    CHALET: Final[str] = "chalet"
    CHANGE_CIRCLE: Final[str] = "change_circle"
    CHANGE_HISTORY: Final[str] = "change_history"
    CHARGING_STATION: Final[str] = "charging_station"
    CHAT: Final[str] = "chat"
    CHAT_BUBBLE: Final[str] = "chat_bubble"
    CHAT_BUBBLE_OUTLINE: Final[str] = "chat_bubble_outline"
    CHECK: Final[str] = "check"
    CHECK_BOX: Final[str] = "check_box"
    CHECK_BOX_OUTLINE_BLANK: Final[str] = "check_box_outline_blank"
    CHECK_CIRCLE: Final[str] = "check_circle"
    CHECK_CIRCLE_OUTLINE: Final[str] = "check_circle_outline"
    CHECKLIST: Final[str] = "checklist"
    CHECKLIST_RTL: Final[str] = "checklist_rtl"
    CHECKROOM: Final[str] = "checkroom"
    CHEVRON_LEFT: Final[str] = "chevron_left"
    CHEVRON_RIGHT: Final[str] = "chevron_right"
    CHILD_CARE: Final[str] = "child_care"
    CHILD_FRIENDLY: Final[str] = "child_friendly"
    CHROME_READER_MODE: Final[str] = "chrome_reader_mode"
    CHURCH: Final[str] = "church"
    CIRCLE: Final[str] = "circle"
    CIRCLE_NOTIFICATIONS: Final[str] = "circle_notifications"
    CLASS: Final[str] = "class"
    CLEAN_HANDS: Final[str] = "clean_hands"
    CLEANING_SERVICES: Final[str] = "cleaning_services"
    CLEAR: Final[str] = "clear"
    CLEAR_ALL: Final[str] = "clear_all"
    CLOSE: Final[str] = "close"
    CLOSE_FULLSCREEN: Final[str] = "close_fullscreen"
    CLOSED_CAPTION: Final[str] = "closed_caption"
    CLOSED_CAPTION_DISABLED: Final[str] = "closed_caption_disabled"
    CLOSED_CAPTION_OFF: Final[str] = "closed_caption_off"
    CLOUD: Final[str] = "cloud"
    CLOUD_CIRCLE: Final[str] = "cloud_circle"
    CLOUD_DONE: Final[str] = "cloud_done"
    CLOUD_DOWNLOAD: Final[str] = "cloud_download"
    CLOUD_OFF: Final[str] = "cloud_off"
    CLOUD_QUEUE: Final[str] = "cloud_queue"
    CLOUD_SYNC: Final[str] = "cloud_sync"
    CLOUD_UPLOAD: Final[str] = "cloud_upload"
    CLOUDY_SNOWING: Final[str] = "cloudy_snowing"
    CO2: Final[str] = "co2"
    CO_PRESENT: Final[str] = "co_present"
    CODE: Final[str] = "code"
    CODE_OFF: Final[str] = "code_off"
    COFFEE: Final[str] = "coffee"
    COFFEE_MAKER: Final[str] = "coffee_maker"
    COLLECTIONS: Final[str] = "collections"
    COLLECTIONS_BOOKMARK: Final[str] = "collections_bookmark"
    COLOR_LENS: Final[str] = "color_lens"
    COLORIZE: Final[str] = "colorize"
    COMMENT: Final[str] = "comment"
    COMMENT_BANK: Final[str] = "comment_bank"
    COMMENTS_DISABLED: Final[str] = "comments_disabled"
    COMMIT: Final[str] = "commit"
    COMMUTE: Final[str] = "commute"
    COMPARE: Final[str] = "compare"
    COMPARE_ARROWS: Final[str] = "compare_arrows"
    COMPASS_CALIBRATION: Final[str] = "compass_calibration"
    COMPOST: Final[str] = "compost"
    COMPRESS: Final[str] = "compress"
    COMPUTER: Final[str] = "computer"
    CONFIRMATION_NUM: Final[str] = "confirmation_num"
    CONFIRMATION_NUMBER: Final[str] = "confirmation_number"
    CONNECT_WITHOUT_CONTACT: Final[str] = "connect_without_contact"
    CONNECTED_TV: Final[str] = "connected_tv"
    CONNECTING_AIRPORTS: Final[str] = "connecting_airports"
    CONSTRUCTION: Final[str] = "construction"
    CONTACT_EMERGENCY: Final[str] = "contact_emergency"
    CONTACT_MAIL: Final[str] = "contact_mail"
    CONTACT_PAGE: Final[str] = "contact_page"
    CONTACT_PHONE: Final[str] = "contact_phone"
    CONTACT_SUPPORT: Final[str] = "contact_support"
    CONTACTLESS: Final[str] = "contactless"
    CONTACTS: Final[str] = "contacts"
    CONTENT_COPY: Final[str] = "content_copy"
    CONTENT_CUT: Final[str] = "content_cut"
    CONTENT_PASTE: Final[str] = "content_paste"
    CONTENT_PASTE_GO: Final[str] = "content_paste_go"
    CONTENT_PASTE_OFF: Final[str] = "content_paste_off"
    CONTENT_PASTE_SEARCH: Final[str] = "content_paste_search"
    CONTRAST: Final[str] = "contrast"
    CONTROL_CAMERA: Final[str] = "control_camera"
    CONTROL_POINT: Final[str] = "control_point"
    CONTROL_POINT_DUPLICATE: Final[str] = "control_point_duplicate"
    CONVEYOR_BELT: Final[str] = "conveyor_belt"
    COOKIE: Final[str] = "cookie"
    COPY_ALL: Final[str] = "copy_all"
    COPYRIGHT: Final[str] = "copyright"
    CORONAVIRUS: Final[str] = "coronavirus"
    CORPORATE_FARE: Final[str] = "corporate_fare"
    COTTAGE: Final[str] = "cottage"
    COUNTERTOPS: Final[str] = "countertops"
    CREATE: Final[str] = "create"
    CREATE_NEW_FOLDER: Final[str] = "create_new_folder"
    CREDIT_CARD: Final[str] = "credit_card"
    CREDIT_CARD_OFF: Final[str] = "credit_card_off"
    CREDIT_SCORE: Final[str] = "credit_score"
    CRIB: Final[str] = "crib"
    CRISIS_ALERT: Final[str] = "crisis_alert"
    CROP: Final[str] = "crop"
    CROP_16_9: Final[str] = "crop_16_9"
    CROP_3_2: Final[str] = "crop_3_2"
    CROP_5_4: Final[str] = "crop_5_4"
    CROP_7_5: Final[str] = "crop_7_5"
    CROP_DIN: Final[str] = "crop_din"
    CROP_FREE: Final[str] = "crop_free"
    CROP_LANDSCAPE: Final[str] = "crop_landscape"
    CROP_ORIGINAL: Final[str] = "crop_original"
    CROP_PORTRAIT: Final[str] = "crop_portrait"
    CROP_ROTATE: Final[str] = "crop_rotate"
    CROP_SQUARE: Final[str] = "crop_square"
    CRUELTY_FREE: Final[str] = "cruelty_free"
    CSS: Final[str] = "css"
    CURRENCY_BITCOIN: Final[str] = "currency_bitcoin"
    CURRENCY_EXCHANGE: Final[str] = "currency_exchange"
    CURRENCY_FRANC: Final[str] = "currency_franc"
    CURRENCY_LIRA: Final[str] = "currency_lira"
    CURRENCY_POUND: Final[str] = "currency_pound"
    CURRENCY_RUBLE: Final[str] = "currency_ruble"
    CURRENCY_RUPEE: Final[str] = "currency_rupee"
    CURRENCY_YEN: Final[str] = "currency_yen"
    CURRENCY_YUAN: Final[str] = "currency_yuan"
    CURTAINS: Final[str] = "curtains"
    CURTAINS_CLOSED: Final[str] = "curtains_closed"
    CYCLONE: Final[str] = "cyclone"
    DANGEROUS: Final[str] = "dangerous"
    DARK_MODE: Final[str] = "dark_mode"
    DASHBOARD: Final[str] = "dashboard"
    DASHBOARD_CUSTOMIZE: Final[str] = "dashboard_customize"
    DATA_ARRAY: Final[str] = "data_array"
    DATA_EXPLORATION: Final[str] = "data_exploration"
    DATA_OBJECT: Final[str] = "data_object"
    DATA_SAVER_OFF: Final[str] = "data_saver_off"
    DATA_SAVER_ON: Final[str] = "data_saver_on"
    DATA_THRESHOLDING: Final[str] = "data_thresholding"
    DATA_USAGE: Final[str] = "data_usage"
    DATASET: Final[str] = "dataset"
    DATASET_LINKED: Final[str] = "dataset_linked"
    DATE_RANGE: Final[str] = "date_range"
    DEBLUR: Final[str] = "deblur"
    DECK: Final[str] = "deck"
    DEHAZE: Final[str] = "dehaze"
    DELETE: Final[str] = "delete"
    DELETE_FOREVER: Final[str] = "delete_forever"
    DELETE_OUTLINE: Final[str] = "delete_outline"
    DELETE_SWEEP: Final[str] = "delete_sweep"
    DELIVERY_DINING: Final[str] = "delivery_dining"
    DENSITY_LARGE: Final[str] = "density_large"
    DENSITY_MEDIUM: Final[str] = "density_medium"
    DENSITY_SMALL: Final[str] = "density_small"
    DEPARTURE_BOARD: Final[str] = "departure_board"
    DESCRIPTION: Final[str] = "description"
    DESELECT: Final[str] = "deselect"
    DESIGN_SERVICES: Final[str] = "design_services"
    DESK: Final[str] = "desk"
    DESKTOP_ACCESS_DISABLED: Final[str] = "desktop_access_disabled"
    DESKTOP_MAC: Final[str] = "desktop_mac"
    DESKTOP_WINDOWS: Final[str] = "desktop_windows"
    DETAILS: Final[str] = "details"
    DEVELOPER_BOARD: Final[str] = "developer_board"
    DEVELOPER_BOARD_OFF: Final[str] = "developer_board_off"
    DEVELOPER_MODE: Final[str] = "developer_mode"
    DEVICE_HUB: Final[str] = "device_hub"
    DEVICE_THERMOSTAT: Final[str] = "device_thermostat"
    DEVICE_UNKNOWN: Final[str] = "device_unknown"
    DEVICES: Final[str] = "devices"
    DEVICES_FOLD: Final[str] = "devices_fold"
    DEVICES_OTHER: Final[str] = "devices_other"
    DEW_POINT: Final[str] = "dew_point"
    DIALER_SIP: Final[str] = "dialer_sip"
    DIALPAD: Final[str] = "dialpad"
    DIAMOND: Final[str] = "diamond"
    DIFFERENCE: Final[str] = "difference"
    DINING: Final[str] = "dining"
    DINNER_DINING: Final[str] = "dinner_dining"
    DIRECTIONS: Final[str] = "directions"
    DIRECTIONS_BIKE: Final[str] = "directions_bike"
    DIRECTIONS_BOAT: Final[str] = "directions_boat"
    DIRECTIONS_BOAT_FILLED: Final[str] = "directions_boat_filled"
    DIRECTIONS_BUS: Final[str] = "directions_bus"
    DIRECTIONS_BUS_FILLED: Final[str] = "directions_bus_filled"
    DIRECTIONS_CAR: Final[str] = "directions_car"
    DIRECTIONS_CAR_FILLED: Final[str] = "directions_car_filled"
    DIRECTIONS_FERRY: Final[str] = "directions_ferry"
    DIRECTIONS_OFF: Final[str] = "directions_off"
    DIRECTIONS_RAILWAY: Final[str] = "directions_railway"
    DIRECTIONS_RAILWAY_FILLED: Final[str] = "directions_railway_filled"
    DIRECTIONS_RUN: Final[str] = "directions_run"
    DIRECTIONS_SUBWAY: Final[str] = "directions_subway"
    DIRECTIONS_SUBWAY_FILLED: Final[str] = "directions_subway_filled"
    DIRECTIONS_TRAIN: Final[str] = "directions_train"
    DIRECTIONS_TRANSIT: Final[str] = "directions_transit"
    DIRECTIONS_TRANSIT_FILLED: Final[str] = "directions_transit_filled"
    DIRECTIONS_WALK: Final[str] = "directions_walk"
    DIRTY_LENS: Final[str] = "dirty_lens"
    DISABLED_BY_DEFAULT: Final[str] = "disabled_by_default"
    DISABLED_VISIBLE: Final[str] = "disabled_visible"
    DISC_FULL: Final[str] = "disc_full"
    DISCORD: Final[str] = "discord"
    DISCOUNT: Final[str] = "discount"
    DISPLAY_SETTINGS: Final[str] = "display_settings"
    DIVERSITY_1: Final[str] = "diversity_1"
    DIVERSITY_2: Final[str] = "diversity_2"
    DIVERSITY_3: Final[str] = "diversity_3"
    DND_FORWARDSLASH: Final[str] = "dnd_forwardslash"
    DNS: Final[str] = "dns"
    DO_DISTURB: Final[str] = "do_disturb"
    DO_DISTURB_ALT: Final[str] = "do_disturb_alt"
    DO_DISTURB_OFF: Final[str] = "do_disturb_off"
    DO_DISTURB_ON: Final[str] = "do_disturb_on"
    DO_NOT_DISTURB: Final[str] = "do_not_disturb"
    DO_NOT_DISTURB_ALT: Final[str] = "do_not_disturb_alt"
    DO_NOT_DISTURB_OFF: Final[str] = "do_not_disturb_off"
    DO_NOT_DISTURB_ON: Final[str] = "do_not_disturb_on"
    DO_NOT_DISTURB_ON_TOTAL_SILENCE: Final[str] = "do_not_disturb_on_total_silence"
    DO_NOT_STEP: Final[str] = "do_not_step"
    DO_NOT_TOUCH: Final[str] = "do_not_touch"
    DOCK: Final[str] = "dock"
    DOCUMENT_SCANNER: Final[str] = "document_scanner"
    DOMAIN: Final[str] = "domain"
    DOMAIN_ADD: Final[str] = "domain_add"
    DOMAIN_DISABLED: Final[str] = "domain_disabled"
    DOMAIN_VERIFICATION: Final[str] = "domain_verification"
    DONE: Final[str] = "done"
    DONE_ALL: Final[str] = "done_all"
    DONE_OUTLINE: Final[str] = "done_outline"
    DONUT_LARGE: Final[str] = "donut_large"
    DONUT_SMALL: Final[str] = "donut_small"
    DOOR_BACK: Final[str] = "door_back"
    DOOR_FRONT: Final[str] = "door_front"
    DOOR_SLIDING: Final[str] = "door_sliding"
    DOORBELL: Final[str] = "doorbell"
    DOUBLE_ARROW: Final[str] = "double_arrow"
    DOWNHILL_SKIING: Final[str] = "downhill_skiing"
    DOWNLOAD: Final[str] = "download"
    DOWNLOAD_DONE: Final[str] = "download_done"
    DOWNLOAD_FOR_OFFLINE: Final[str] = "download_for_offline"
    DOWNLOADING: Final[str] = "downloading"
    DRAFTS: Final[str] = "drafts"
    DRAG_HANDLE: Final[str] = "drag_handle"
    DRAG_INDICATOR: Final[str] = "drag_indicator"
    DRAW: Final[str] = "draw"
    DRIVE_ETA: Final[str] = "drive_eta"
    DRIVE_FILE_MOVE: Final[str] = "drive_file_move"
    DRIVE_FILE_MOVE_OUTLINE: Final[str] = "drive_file_move_outline"
    DRIVE_FILE_MOVE_RTL: Final[str] = "drive_file_move_rtl"
    DRIVE_FILE_RENAME_OUTLINE: Final[str] = "drive_file_rename_outline"
    DRIVE_FOLDER_UPLOAD: Final[str] = "drive_folder_upload"
    DRY: Final[str] = "dry"
    DRY_CLEANING: Final[str] = "dry_cleaning"
    DUO: Final[str] = "duo"
    DVR: Final[str] = "dvr"
    DYNAMIC_FEED: Final[str] = "dynamic_feed"
    DYNAMIC_FORM: Final[str] = "dynamic_form"
    E_MOBILEDATA: Final[str] = "e_mobiledata"
    EARBUDS: Final[str] = "earbuds"
    EARBUDS_BATTERY: Final[str] = "earbuds_battery"
    EAST: Final[str] = "east"
    ECO: Final[str] = "eco"
    EDGESENSOR_HIGH: Final[str] = "edgesensor_high"
    EDGESENSOR_LOW: Final[str] = "edgesensor_low"
    EDIT: Final[str] = "edit"
    EDIT_ATTRIBUTES: Final[str] = "edit_attributes"
    EDIT_CALENDAR: Final[str] = "edit_calendar"
    EDIT_DOCUMENT: Final[str] = "edit_document"
    EDIT_LOCATION: Final[str] = "edit_location"
    EDIT_LOCATION_ALT: Final[str] = "edit_location_alt"
    EDIT_NOTE: Final[str] = "edit_note"
    EDIT_NOTIFICATIONS: Final[str] = "edit_notifications"
    EDIT_OFF: Final[str] = "edit_off"
    EDIT_ROAD: Final[str] = "edit_road"
    EDIT_SQUARE: Final[str] = "edit_square"
    EGG: Final[str] = "egg"
    EGG_ALT: Final[str] = "egg_alt"
    EJECT: Final[str] = "eject"
    ELDERLY: Final[str] = "elderly"
    ELDERLY_WOMAN: Final[str] = "elderly_woman"
    ELECTRIC_BIKE: Final[str] = "electric_bike"
    ELECTRIC_BOLT: Final[str] = "electric_bolt"
    ELECTRIC_CAR: Final[str] = "electric_car"
    ELECTRIC_METER: Final[str] = "electric_meter"
    ELECTRIC_MOPED: Final[str] = "electric_moped"
    ELECTRIC_RICKSHAW: Final[str] = "electric_rickshaw"
    ELECTRIC_SCOOTER: Final[str] = "electric_scooter"
    ELECTRICAL_SERVICES: Final[str] = "electrical_services"
    ELEVATOR: Final[str] = "elevator"
    EMAIL: Final[str] = "email"
    EMERGENCY: Final[str] = "emergency"
    EMERGENCY_RECORDING: Final[str] = "emergency_recording"
    EMERGENCY_SHARE: Final[str] = "emergency_share"
    EMOJI_EMOTIONS: Final[str] = "emoji_emotions"
    EMOJI_EVENTS: Final[str] = "emoji_events"
    EMOJI_FLAGS: Final[str] = "emoji_flags"
    EMOJI_FOOD_BEVERAGE: Final[str] = "emoji_food_beverage"
    EMOJI_NATURE: Final[str] = "emoji_nature"
    EMOJI_OBJECTS: Final[str] = "emoji_objects"
    EMOJI_PEOPLE: Final[str] = "emoji_people"
    EMOJI_SYMBOLS: Final[str] = "emoji_symbols"
    EMOJI_TRANSPORTATION: Final[str] = "emoji_transportation"
    ENERGY_SAVINGS_LEAF: Final[str] = "energy_savings_leaf"
    ENGINEERING: Final[str] = "engineering"
    ENHANCE_PHOTO_TRANSLATE: Final[str] = "enhance_photo_translate"
    ENHANCED_ENCRYPTION: Final[str] = "enhanced_encryption"
    EQUALIZER: Final[str] = "equalizer"
    ERROR: Final[str] = "error"
    ERROR_OUTLINE: Final[str] = "error_outline"
    ESCALATOR: Final[str] = "escalator"
    ESCALATOR_WARNING: Final[str] = "escalator_warning"
    EURO: Final[str] = "euro"
    EURO_SYMBOL: Final[str] = "euro_symbol"
    EV_STATION: Final[str] = "ev_station"
    EVENT: Final[str] = "event"
    EVENT_AVAILABLE: Final[str] = "event_available"
    EVENT_BUSY: Final[str] = "event_busy"
    EVENT_NOTE: Final[str] = "event_note"
    EVENT_REPEAT: Final[str] = "event_repeat"
    EVENT_SEAT: Final[str] = "event_seat"
    EXIT_TO_APP: Final[str] = "exit_to_app"
    EXPAND: Final[str] = "expand"
    EXPAND_CIRCLE_DOWN: Final[str] = "expand_circle_down"
    EXPAND_LESS: Final[str] = "expand_less"
    EXPAND_MORE: Final[str] = "expand_more"
    EXPLICIT: Final[str] = "explicit"
    EXPLORE: Final[str] = "explore"
    EXPLORE_OFF: Final[str] = "explore_off"
    EXPOSURE: Final[str] = "exposure"
    EXPOSURE_MINUS_1: Final[str] = "exposure_minus_1"
    EXPOSURE_MINUS_2: Final[str] = "exposure_minus_2"
    EXPOSURE_NEG_1: Final[str] = "exposure_neg_1"
    EXPOSURE_NEG_2: Final[str] = "exposure_neg_2"
    EXPOSURE_PLUS_1: Final[str] = "exposure_plus_1"
    EXPOSURE_PLUS_2: Final[str] = "exposure_plus_2"
    EXPOSURE_ZERO: Final[str] = "exposure_zero"
    EXTENSION: Final[str] = "extension"
    EXTENSION_OFF: Final[str] = "extension_off"
    FACE: Final[str] = "face"
    FACE_2: Final[str] = "face_2"
    FACE_3: Final[str] = "face_3"
    FACE_4: Final[str] = "face_4"
    FACE_5: Final[str] = "face_5"
    FACE_6: Final[str] = "face_6"
    FACE_RETOUCHING_NATURAL: Final[str] = "face_retouching_natural"
    FACE_RETOUCHING_OFF: Final[str] = "face_retouching_off"
    FACEBOOK: Final[str] = "facebook"
    FACT_CHECK: Final[str] = "fact_check"
    FACTORY: Final[str] = "factory"
    FAMILY_RESTROOM: Final[str] = "family_restroom"
    FAST_FORWARD: Final[str] = "fast_forward"
    FAST_REWIND: Final[str] = "fast_rewind"
    FASTFOOD: Final[str] = "fastfood"
    FAVORITE: Final[str] = "favorite"
    FAVORITE_BORDER: Final[str] = "favorite_border"
    FAVORITE_OUTLINE: Final[str] = "favorite_outline"
    FAX: Final[str] = "fax"
    FEATURED_PLAY_LIST: Final[str] = "featured_play_list"
    FEATURED_VIDEO: Final[str] = "featured_video"
    FEED: Final[str] = "feed"
    FEEDBACK: Final[str] = "feedback"
    FEMALE: Final[str] = "female"
    FENCE: Final[str] = "fence"
    FESTIVAL: Final[str] = "festival"
    FIBER_DVR: Final[str] = "fiber_dvr"
    FIBER_MANUAL_RECORD: Final[str] = "fiber_manual_record"
    FIBER_NEW: Final[str] = "fiber_new"
    FIBER_PIN: Final[str] = "fiber_pin"
    FIBER_SMART_RECORD: Final[str] = "fiber_smart_record"
    FILE_COPY: Final[str] = "file_copy"
    FILE_DOWNLOAD: Final[str] = "file_download"
    FILE_DOWNLOAD_DONE: Final[str] = "file_download_done"
    FILE_DOWNLOAD_OFF: Final[str] = "file_download_off"
    FILE_OPEN: Final[str] = "file_open"
    FILE_PRESENT: Final[str] = "file_present"
    FILE_UPLOAD: Final[str] = "file_upload"
    FILE_UPLOAD_OFF: Final[str] = "file_upload_off"
    FILTER: Final[str] = "filter"
    FILTER_1: Final[str] = "filter_1"
    FILTER_2: Final[str] = "filter_2"
    FILTER_3: Final[str] = "filter_3"
    FILTER_4: Final[str] = "filter_4"
    FILTER_5: Final[str] = "filter_5"
    FILTER_6: Final[str] = "filter_6"
    FILTER_7: Final[str] = "filter_7"
    FILTER_8: Final[str] = "filter_8"
    FILTER_9: Final[str] = "filter_9"
    FILTER_9_PLUS: Final[str] = "filter_9_plus"
    FILTER_ALT: Final[str] = "filter_alt"
    FILTER_ALT_OFF: Final[str] = "filter_alt_off"
    FILTER_B_AND_W: Final[str] = "filter_b_and_w"
    FILTER_CENTER_FOCUS: Final[str] = "filter_center_focus"
    FILTER_DRAMA: Final[str] = "filter_drama"
    FILTER_FRAMES: Final[str] = "filter_frames"
    FILTER_HDR: Final[str] = "filter_hdr"
    FILTER_LIST: Final[str] = "filter_list"
    FILTER_LIST_ALT: Final[str] = "filter_list_alt"
    FILTER_LIST_OFF: Final[str] = "filter_list_off"
    FILTER_NONE: Final[str] = "filter_none"
    FILTER_TILT_SHIFT: Final[str] = "filter_tilt_shift"
    FILTER_VINTAGE: Final[str] = "filter_vintage"
    FIND_IN_PAGE: Final[str] = "find_in_page"
    FIND_REPLACE: Final[str] = "find_replace"
    FINGERPRINT: Final[str] = "fingerprint"
    FIRE_EXTINGUISHER: Final[str] = "fire_extinguisher"
    FIRE_HYDRANT: Final[str] = "fire_hydrant"
    FIRE_HYDRANT_ALT: Final[str] = "fire_hydrant_alt"
    FIRE_TRUCK: Final[str] = "fire_truck"
    FIREPLACE: Final[str] = "fireplace"
    FIRST_PAGE: Final[str] = "first_page"
    FIT_SCREEN: Final[str] = "fit_screen"
    FITBIT: Final[str] = "fitbit"
    FITNESS_CENTER: Final[str] = "fitness_center"
    FLAG: Final[str] = "flag"
    FLAG_CIRCLE: Final[str] = "flag_circle"
    FLAKY: Final[str] = "flaky"
    FLARE: Final[str] = "flare"
    FLASH_AUTO: Final[str] = "flash_auto"
    FLASH_OFF: Final[str] = "flash_off"
    FLASH_ON: Final[str] = "flash_on"
    FLASHLIGHT_OFF: Final[str] = "flashlight_off"
    FLASHLIGHT_ON: Final[str] = "flashlight_on"
    FLATWARE: Final[str] = "flatware"
    FLIGHT: Final[str] = "flight"
    FLIGHT_CLASS: Final[str] = "flight_class"
    FLIGHT_LAND: Final[str] = "flight_land"
    FLIGHT_TAKEOFF: Final[str] = "flight_takeoff"
    FLIP: Final[str] = "flip"
    FLIP_CAMERA_ANDROID: Final[str] = "flip_camera_android"
    FLIP_CAMERA_IOS: Final[str] = "flip_camera_ios"
    FLIP_TO_BACK: Final[str] = "flip_to_back"
    FLIP_TO_FRONT: Final[str] = "flip_to_front"
    FLOOD: Final[str] = "flood"
    FLOURESCENT: Final[str] = "flourescent"
    FLUORESCENT: Final[str] = "fluorescent"
    FLUTTER_DASH: Final[str] = "flutter_dash"
    FMD_BAD: Final[str] = "fmd_bad"
    FMD_GOOD: Final[str] = "fmd_good"
    FOGGY: Final[str] = "foggy"
    FOLDER: Final[str] = "folder"
    FOLDER_COPY: Final[str] = "folder_copy"
    FOLDER_DELETE: Final[str] = "folder_delete"
    FOLDER_OFF: Final[str] = "folder_off"
    FOLDER_OPEN: Final[str] = "folder_open"
    FOLDER_SHARED: Final[str] = "folder_shared"
    FOLDER_SPECIAL: Final[str] = "folder_special"
    FOLDER_ZIP: Final[str] = "folder_zip"
    FOLLOW_THE_SIGNS: Final[str] = "follow_the_signs"
    FONT_DOWNLOAD: Final[str] = "font_download"
    FONT_DOWNLOAD_OFF: Final[str] = "font_download_off"
    FOOD_BANK: Final[str] = "food_bank"
    FOREST: Final[str] = "forest"
    FORK_LEFT: Final[str] = "fork_left"
    FORK_RIGHT: Final[str] = "fork_right"
    FORKLIFT: Final[str] = "forklift"
    FORMAT_ALIGN_CENTER: Final[str] = "format_align_center"
    FORMAT_ALIGN_JUSTIFY: Final[str] = "format_align_justify"
    FORMAT_ALIGN_LEFT: Final[str] = "format_align_left"
    FORMAT_ALIGN_RIGHT: Final[str] = "format_align_right"
    FORMAT_BOLD: Final[str] = "format_bold"
    FORMAT_CLEAR: Final[str] = "format_clear"
    FORMAT_COLOR_FILL: Final[str] = "format_color_fill"
    FORMAT_COLOR_RESET: Final[str] = "format_color_reset"
    FORMAT_COLOR_TEXT: Final[str] = "format_color_text"
    FORMAT_INDENT_DECREASE: Final[str] = "format_indent_decrease"
    FORMAT_INDENT_INCREASE: Final[str] = "format_indent_increase"
    FORMAT_ITALIC: Final[str] = "format_italic"
    FORMAT_LINE_SPACING: Final[str] = "format_line_spacing"
    FORMAT_LIST_BULLETED: Final[str] = "format_list_bulleted"
    FORMAT_LIST_BULLETED_ADD: Final[str] = "format_list_bulleted_add"
    FORMAT_LIST_NUMBERED: Final[str] = "format_list_numbered"
    FORMAT_LIST_NUMBERED_RTL: Final[str] = "format_list_numbered_rtl"
    FORMAT_OVERLINE: Final[str] = "format_overline"
    FORMAT_PAINT: Final[str] = "format_paint"
    FORMAT_QUOTE: Final[str] = "format_quote"
    FORMAT_SHAPES: Final[str] = "format_shapes"
    FORMAT_SIZE: Final[str] = "format_size"
    FORMAT_STRIKETHROUGH: Final[str] = "format_strikethrough"
    FORMAT_TEXTDIRECTION_L_TO_R: Final[str] = "format_textdirection_l_to_r"
    FORMAT_TEXTDIRECTION_R_TO_L: Final[str] = "format_textdirection_r_to_l"
    FORMAT_UNDERLINE: Final[str] = "format_underline"
    FORMAT_UNDERLINED: Final[str] = "format_underlined"
    FORT: Final[str] = "fort"
    FORUM: Final[str] = "forum"
    FORWARD: Final[str] = "forward"
    FORWARD_10: Final[str] = "forward_10"
    FORWARD_30: Final[str] = "forward_30"
    FORWARD_5: Final[str] = "forward_5"
    FORWARD_TO_INBOX: Final[str] = "forward_to_inbox"
    FOUNDATION: Final[str] = "foundation"
    FREE_BREAKFAST: Final[str] = "free_breakfast"
    FREE_CANCELLATION: Final[str] = "free_cancellation"
    FRONT_HAND: Final[str] = "front_hand"
    FRONT_LOADER: Final[str] = "front_loader"
    FULLSCREEN: Final[str] = "fullscreen"
    FULLSCREEN_EXIT: Final[str] = "fullscreen_exit"
    FUNCTIONS: Final[str] = "functions"
    G_MOBILEDATA: Final[str] = "g_mobiledata"
    G_TRANSLATE: Final[str] = "g_translate"
    GAMEPAD: Final[str] = "gamepad"
    GAMES: Final[str] = "games"
    GARAGE: Final[str] = "garage"
    GAS_METER: Final[str] = "gas_meter"
    GAVEL: Final[str] = "gavel"
    GENERATING_TOKENS: Final[str] = "generating_tokens"
    GESTURE: Final[str] = "gesture"
    GET_APP: Final[str] = "get_app"
    GIF: Final[str] = "gif"
    GIF_BOX: Final[str] = "gif_box"
    GIRL: Final[str] = "girl"
    GITE: Final[str] = "gite"
    GOAT: Final[str] = "goat"
    GOLF_COURSE: Final[str] = "golf_course"
    GPP_BAD: Final[str] = "gpp_bad"
    GPP_GOOD: Final[str] = "gpp_good"
    GPP_MAYBE: Final[str] = "gpp_maybe"
    GPS_FIXED: Final[str] = "gps_fixed"
    GPS_NOT_FIXED: Final[str] = "gps_not_fixed"
    GPS_OFF: Final[str] = "gps_off"
    GRADE: Final[str] = "grade"
    GRADIENT: Final[str] = "gradient"
    GRADING: Final[str] = "grading"
    GRAIN: Final[str] = "grain"
    GRAPHIC_EQ: Final[str] = "graphic_eq"
    GRASS: Final[str] = "grass"
    GRID_3X3: Final[str] = "grid_3x3"
    GRID_4X4: Final[str] = "grid_4x4"
    GRID_GOLDENRATIO: Final[str] = "grid_goldenratio"
    GRID_OFF: Final[str] = "grid_off"
    GRID_ON: Final[str] = "grid_on"
    GRID_VIEW: Final[str] = "grid_view"
    GROUP: Final[str] = "group"
    GROUP_ADD: Final[str] = "group_add"
    GROUP_OFF: Final[str] = "group_off"
    GROUP_REMOVE: Final[str] = "group_remove"
    GROUP_WORK: Final[str] = "group_work"
    GROUPS: Final[str] = "groups"
    GROUPS_2: Final[str] = "groups_2"
    GROUPS_3: Final[str] = "groups_3"
    H_MOBILEDATA: Final[str] = "h_mobiledata"
    H_PLUS_MOBILEDATA: Final[str] = "h_plus_mobiledata"
    HAIL: Final[str] = "hail"
    HANDSHAKE: Final[str] = "handshake"
    HANDYMAN: Final[str] = "handyman"
    HARDWARE: Final[str] = "hardware"
    HD: Final[str] = "hd"
    HDR_AUTO: Final[str] = "hdr_auto"
    HDR_AUTO_SELECT: Final[str] = "hdr_auto_select"
    HDR_ENHANCED_SELECT: Final[str] = "hdr_enhanced_select"
    HDR_OFF: Final[str] = "hdr_off"
    HDR_OFF_SELECT: Final[str] = "hdr_off_select"
    HDR_ON: Final[str] = "hdr_on"
    HDR_ON_SELECT: Final[str] = "hdr_on_select"
    HDR_PLUS: Final[str] = "hdr_plus"
    HDR_STRONG: Final[str] = "hdr_strong"
    HDR_WEAK: Final[str] = "hdr_weak"
    HEADPHONES: Final[str] = "headphones"
    HEADPHONES_BATTERY: Final[str] = "headphones_battery"
    HEADSET: Final[str] = "headset"
    HEADSET_MIC: Final[str] = "headset_mic"
    HEADSET_OFF: Final[str] = "headset_off"
    HEALING: Final[str] = "healing"
    HEALTH_AND_SAFETY: Final[str] = "health_and_safety"
    HEARING: Final[str] = "hearing"
    HEARING_DISABLED: Final[str] = "hearing_disabled"
    HEART_BROKEN: Final[str] = "heart_broken"
    HEAT_PUMP: Final[str] = "heat_pump"
    HEIGHT: Final[str] = "height"
    HELP: Final[str] = "help"
    HELP_CENTER: Final[str] = "help_center"
    HELP_OUTLINE: Final[str] = "help_outline"
    HEVC: Final[str] = "hevc"
    HEXAGON: Final[str] = "hexagon"
    HIDE_IMAGE: Final[str] = "hide_image"
    HIDE_SOURCE: Final[str] = "hide_source"
    HIGH_QUALITY: Final[str] = "high_quality"
    HIGHLIGHT: Final[str] = "highlight"
    HIGHLIGHT_ALT: Final[str] = "highlight_alt"
    HIGHLIGHT_OFF: Final[str] = "highlight_off"
    HIGHLIGHT_REMOVE: Final[str] = "highlight_remove"
    HIKING: Final[str] = "hiking"
    HISTORY: Final[str] = "history"
    HISTORY_EDU: Final[str] = "history_edu"
    HISTORY_TOGGLE_OFF: Final[str] = "history_toggle_off"
    HIVE: Final[str] = "hive"
    HLS: Final[str] = "hls"
    HLS_OFF: Final[str] = "hls_off"
    HOLIDAY_VILLAGE: Final[str] = "holiday_village"
    HOME: Final[str] = "home"
    HOME_FILLED: Final[str] = "home_filled"
    HOME_MAX: Final[str] = "home_max"
    HOME_MINI: Final[str] = "home_mini"
    HOME_REPAIR_SERVICE: Final[str] = "home_repair_service"
    HOME_WORK: Final[str] = "home_work"
    HORIZONTAL_DISTRIBUTE: Final[str] = "horizontal_distribute"
    HORIZONTAL_RULE: Final[str] = "horizontal_rule"
    HORIZONTAL_SPLIT: Final[str] = "horizontal_split"
    HOT_TUB: Final[str] = "hot_tub"
    HOTEL: Final[str] = "hotel"
    HOTEL_CLASS: Final[str] = "hotel_class"
    HOURGLASS_BOTTOM: Final[str] = "hourglass_bottom"
    HOURGLASS_DISABLED: Final[str] = "hourglass_disabled"
    HOURGLASS_EMPTY: Final[str] = "hourglass_empty"
    HOURGLASS_FULL: Final[str] = "hourglass_full"
    HOURGLASS_TOP: Final[str] = "hourglass_top"
    HOUSE: Final[str] = "house"
    HOUSE_SIDING: Final[str] = "house_siding"
    HOUSEBOAT: Final[str] = "houseboat"
    HOW_TO_REG: Final[str] = "how_to_reg"
    HOW_TO_VOTE: Final[str] = "how_to_vote"
    HTML: Final[str] = "html"
    HTTP: Final[str] = "http"
    HTTPS: Final[str] = "https"
    HUB: Final[str] = "hub"
    HVAC: Final[str] = "hvac"
    ICE_SKATING: Final[str] = "ice_skating"
    ICECREAM: Final[str] = "icecream"
    IMAGE: Final[str] = "image"
    IMAGE_ASPECT_RATIO: Final[str] = "image_aspect_ratio"
    IMAGE_NOT_SUPPORTED: Final[str] = "image_not_supported"
    IMAGE_SEARCH: Final[str] = "image_search"
    IMAGESEARCH_ROLLER: Final[str] = "imagesearch_roller"
    IMPORT_CONTACTS: Final[str] = "import_contacts"
    IMPORT_EXPORT: Final[str] = "import_export"
    IMPORTANT_DEVICES: Final[str] = "important_devices"
    INBOX: Final[str] = "inbox"
    INCOMPLETE_CIRCLE: Final[str] = "incomplete_circle"
    INDETERMINATE_CHECK_BOX: Final[str] = "indeterminate_check_box"
    INFO: Final[str] = "info"
    INFO_OUTLINE: Final[str] = "info_outline"
    INPUT: Final[str] = "input"
    INSERT_CHART: Final[str] = "insert_chart"
    INSERT_CHART_OUTLINED: Final[str] = "insert_chart_outlined"
    INSERT_COMMENT: Final[str] = "insert_comment"
    INSERT_DRIVE_FILE: Final[str] = "insert_drive_file"
    INSERT_EMOTICON: Final[str] = "insert_emoticon"
    INSERT_INVITATION: Final[str] = "insert_invitation"
    INSERT_LINK: Final[str] = "insert_link"
    INSERT_PAGE_BREAK: Final[str] = "insert_page_break"
    INSERT_PHOTO: Final[str] = "insert_photo"
    INSIGHTS: Final[str] = "insights"
    INSTALL_DESKTOP: Final[str] = "install_desktop"
    INSTALL_MOBILE: Final[str] = "install_mobile"
    INTEGRATION_INSTRUCTIONS: Final[str] = "integration_instructions"
    INTERESTS: Final[str] = "interests"
    INTERPRETER_MODE: Final[str] = "interpreter_mode"
    INVENTORY: Final[str] = "inventory"
    INVENTORY_2: Final[str] = "inventory_2"
    INVERT_COLORS: Final[str] = "invert_colors"
    INVERT_COLORS_OFF: Final[str] = "invert_colors_off"
    INVERT_COLORS_ON: Final[str] = "invert_colors_on"
    IOS_SHARE: Final[str] = "ios_share"
    IRON: Final[str] = "iron"
    ISO: Final[str] = "iso"
    JAVASCRIPT: Final[str] = "javascript"
    JOIN_FULL: Final[str] = "join_full"
    JOIN_INNER: Final[str] = "join_inner"
    JOIN_LEFT: Final[str] = "join_left"
    JOIN_RIGHT: Final[str] = "join_right"
    KAYAKING: Final[str] = "kayaking"
    KEBAB_DINING: Final[str] = "kebab_dining"
    KEY: Final[str] = "key"
    KEY_OFF: Final[str] = "key_off"
    KEYBOARD: Final[str] = "keyboard"
    KEYBOARD_ALT: Final[str] = "keyboard_alt"
    KEYBOARD_ARROW_DOWN: Final[str] = "keyboard_arrow_down"
    KEYBOARD_ARROW_LEFT: Final[str] = "keyboard_arrow_left"
    KEYBOARD_ARROW_RIGHT: Final[str] = "keyboard_arrow_right"
    KEYBOARD_ARROW_UP: Final[str] = "keyboard_arrow_up"
    KEYBOARD_BACKSPACE: Final[str] = "keyboard_backspace"
    KEYBOARD_CAPSLOCK: Final[str] = "keyboard_capslock"
    KEYBOARD_COMMAND: Final[str] = "keyboard_command"
    KEYBOARD_COMMAND_KEY: Final[str] = "keyboard_command_key"
    KEYBOARD_CONTROL: Final[str] = "keyboard_control"
    KEYBOARD_CONTROL_KEY: Final[str] = "keyboard_control_key"
    KEYBOARD_DOUBLE_ARROW_DOWN: Final[str] = "keyboard_double_arrow_down"
    KEYBOARD_DOUBLE_ARROW_LEFT: Final[str] = "keyboard_double_arrow_left"
    KEYBOARD_DOUBLE_ARROW_RIGHT: Final[str] = "keyboard_double_arrow_right"
    KEYBOARD_DOUBLE_ARROW_UP: Final[str] = "keyboard_double_arrow_up"
    KEYBOARD_HIDE: Final[str] = "keyboard_hide"
    KEYBOARD_OPTION: Final[str] = "keyboard_option"
    KEYBOARD_OPTION_KEY: Final[str] = "keyboard_option_key"
    KEYBOARD_RETURN: Final[str] = "keyboard_return"
    KEYBOARD_TAB: Final[str] = "keyboard_tab"
    KEYBOARD_VOICE: Final[str] = "keyboard_voice"
    KING_BED: Final[str] = "king_bed"
    KITCHEN: Final[str] = "kitchen"
    KITESURFING: Final[str] = "kitesurfing"
    LABEL: Final[str] = "label"
    LABEL_IMPORTANT: Final[str] = "label_important"
    LABEL_IMPORTANT_OUTLINE: Final[str] = "label_important_outline"
    LABEL_OFF: Final[str] = "label_off"
    LABEL_OUTLINE: Final[str] = "label_outline"
    LAN: Final[str] = "lan"
    LANDSCAPE: Final[str] = "landscape"
    LANDSLIDE: Final[str] = "landslide"
    LANGUAGE: Final[str] = "language"
    LAPTOP: Final[str] = "laptop"
    LAPTOP_CHROMEBOOK: Final[str] = "laptop_chromebook"
    LAPTOP_MAC: Final[str] = "laptop_mac"
    LAPTOP_WINDOWS: Final[str] = "laptop_windows"
    LAST_PAGE: Final[str] = "last_page"
    LAUNCH: Final[str] = "launch"
    LAYERS: Final[str] = "layers"
    LAYERS_CLEAR: Final[str] = "layers_clear"
    LEADERBOARD: Final[str] = "leaderboard"
    LEAK_ADD: Final[str] = "leak_add"
    LEAK_REMOVE: Final[str] = "leak_remove"
    LEAVE_BAGS_AT_HOME: Final[str] = "leave_bags_at_home"
    LEGEND_TOGGLE: Final[str] = "legend_toggle"
    LENS: Final[str] = "lens"
    LENS_BLUR: Final[str] = "lens_blur"
    LIBRARY_ADD: Final[str] = "library_add"
    LIBRARY_ADD_CHECK: Final[str] = "library_add_check"
    LIBRARY_BOOKS: Final[str] = "library_books"
    LIBRARY_MUSIC: Final[str] = "library_music"
    LIGHT: Final[str] = "light"
    LIGHT_MODE: Final[str] = "light_mode"
    LIGHTBULB: Final[str] = "lightbulb"
    LIGHTBULB_CIRCLE: Final[str] = "lightbulb_circle"
    LIGHTBULB_OUTLINE: Final[str] = "lightbulb_outline"
    LINE_AXIS: Final[str] = "line_axis"
    LINE_STYLE: Final[str] = "line_style"
    LINE_WEIGHT: Final[str] = "line_weight"
    LINEAR_SCALE: Final[str] = "linear_scale"
    LINK: Final[str] = "link"
    LINK_OFF: Final[str] = "link_off"
    LINKED_CAMERA: Final[str] = "linked_camera"
    LIQUOR: Final[str] = "liquor"
    LIST: Final[str] = "list"
    LIST_ALT: Final[str] = "list_alt"
    LIVE_HELP: Final[str] = "live_help"
    LIVE_TV: Final[str] = "live_tv"
    LIVING: Final[str] = "living"
    LOCAL_ACTIVITY: Final[str] = "local_activity"
    LOCAL_AIRPORT: Final[str] = "local_airport"
    LOCAL_ATM: Final[str] = "local_atm"
    LOCAL_ATTRACTION: Final[str] = "local_attraction"
    LOCAL_BAR: Final[str] = "local_bar"
    LOCAL_CAFE: Final[str] = "local_cafe"
    LOCAL_CAR_WASH: Final[str] = "local_car_wash"
    LOCAL_CONVENIENCE_STORE: Final[str] = "local_convenience_store"
    LOCAL_DINING: Final[str] = "local_dining"
    LOCAL_DRINK: Final[str] = "local_drink"
    LOCAL_FIRE_DEPARTMENT: Final[str] = "local_fire_department"
    LOCAL_FLORIST: Final[str] = "local_florist"
    LOCAL_GAS_STATION: Final[str] = "local_gas_station"
    LOCAL_GROCERY_STORE: Final[str] = "local_grocery_store"
    LOCAL_HOSPITAL: Final[str] = "local_hospital"
    LOCAL_HOTEL: Final[str] = "local_hotel"
    LOCAL_LAUNDRY_SERVICE: Final[str] = "local_laundry_service"
    LOCAL_LIBRARY: Final[str] = "local_library"
    LOCAL_MALL: Final[str] = "local_mall"
    LOCAL_MOVIES: Final[str] = "local_movies"
    LOCAL_OFFER: Final[str] = "local_offer"
    LOCAL_PARKING: Final[str] = "local_parking"
    LOCAL_PHARMACY: Final[str] = "local_pharmacy"
    LOCAL_PHONE: Final[str] = "local_phone"
    LOCAL_PIZZA: Final[str] = "local_pizza"
    LOCAL_PLAY: Final[str] = "local_play"
    LOCAL_POLICE: Final[str] = "local_police"
    LOCAL_POST_OFFICE: Final[str] = "local_post_office"
    LOCAL_PRINT_SHOP: Final[str] = "local_print_shop"
    LOCAL_PRINTSHOP: Final[str] = "local_printshop"
    LOCAL_RESTAURANT: Final[str] = "local_restaurant"
    LOCAL_SEE: Final[str] = "local_see"
    LOCAL_SHIPPING: Final[str] = "local_shipping"
    LOCAL_TAXI: Final[str] = "local_taxi"
    LOCATION_CITY: Final[str] = "location_city"
    LOCATION_DISABLED: Final[str] = "location_disabled"
    LOCATION_HISTORY: Final[str] = "location_history"
    LOCATION_OFF: Final[str] = "location_off"
    LOCATION_ON: Final[str] = "location_on"
    LOCATION_PIN: Final[str] = "location_pin"
    LOCATION_SEARCHING: Final[str] = "location_searching"
    LOCK: Final[str] = "lock"
    LOCK_CLOCK: Final[str] = "lock_clock"
    LOCK_OPEN: Final[str] = "lock_open"
    LOCK_OUTLINE: Final[str] = "lock_outline"
    LOCK_PERSON: Final[str] = "lock_person"
    LOCK_RESET: Final[str] = "lock_reset"
    LOGIN: Final[str] = "login"
    LOGO_DEV: Final[str] = "logo_dev"
    LOGOUT: Final[str] = "logout"
    LOOKS: Final[str] = "looks"
    LOOKS_3: Final[str] = "looks_3"
    LOOKS_4: Final[str] = "looks_4"
    LOOKS_5: Final[str] = "looks_5"
    LOOKS_6: Final[str] = "looks_6"
    LOOKS_ONE: Final[str] = "looks_one"
    LOOKS_TWO: Final[str] = "looks_two"
    LOOP: Final[str] = "loop"
    LOUPE: Final[str] = "loupe"
    LOW_PRIORITY: Final[str] = "low_priority"
    LOYALTY: Final[str] = "loyalty"
    LTE_MOBILEDATA: Final[str] = "lte_mobiledata"
    LTE_PLUS_MOBILEDATA: Final[str] = "lte_plus_mobiledata"
    LUGGAGE: Final[str] = "luggage"
    LUNCH_DINING: Final[str] = "lunch_dining"
    LYRICS: Final[str] = "lyrics"
    MACRO_OFF: Final[str] = "macro_off"
    MAIL: Final[str] = "mail"
    MAIL_LOCK: Final[str] = "mail_lock"
    MAIL_OUTLINE: Final[str] = "mail_outline"
    MALE: Final[str] = "male"
    MAN: Final[str] = "man"
    MAN_2: Final[str] = "man_2"
    MAN_3: Final[str] = "man_3"
    MAN_4: Final[str] = "man_4"
    MANAGE_ACCOUNTS: Final[str] = "manage_accounts"
    MANAGE_HISTORY: Final[str] = "manage_history"
    MANAGE_SEARCH: Final[str] = "manage_search"
    MAP: Final[str] = "map"
    MAPS_HOME_WORK: Final[str] = "maps_home_work"
    MAPS_UGC: Final[str] = "maps_ugc"
    MARGIN: Final[str] = "margin"
    MARK_AS_UNREAD: Final[str] = "mark_as_unread"
    MARK_CHAT_READ: Final[str] = "mark_chat_read"
    MARK_CHAT_UNREAD: Final[str] = "mark_chat_unread"
    MARK_EMAIL_READ: Final[str] = "mark_email_read"
    MARK_EMAIL_UNREAD: Final[str] = "mark_email_unread"
    MARK_UNREAD_CHAT_ALT: Final[str] = "mark_unread_chat_alt"
    MARKUNREAD: Final[str] = "markunread"
    MARKUNREAD_MAILBOX: Final[str] = "markunread_mailbox"
    MASKS: Final[str] = "masks"
    MAXIMIZE: Final[str] = "maximize"
    MEDIA_BLUETOOTH_OFF: Final[str] = "media_bluetooth_off"
    MEDIA_BLUETOOTH_ON: Final[str] = "media_bluetooth_on"
    MEDIATION: Final[str] = "mediation"
    MEDICAL_INFORMATION: Final[str] = "medical_information"
    MEDICAL_SERVICES: Final[str] = "medical_services"
    MEDICATION: Final[str] = "medication"
    MEDICATION_LIQUID: Final[str] = "medication_liquid"
    MEETING_ROOM: Final[str] = "meeting_room"
    MEMORY: Final[str] = "memory"
    MENU: Final[str] = "menu"
    MENU_BOOK: Final[str] = "menu_book"
    MENU_OPEN: Final[str] = "menu_open"
    MERGE: Final[str] = "merge"
    MERGE_TYPE: Final[str] = "merge_type"
    MESSAGE: Final[str] = "message"
    MESSENGER: Final[str] = "messenger"
    MESSENGER_OUTLINE: Final[str] = "messenger_outline"
    MIC: Final[str] = "mic"
    MIC_EXTERNAL_OFF: Final[str] = "mic_external_off"
    MIC_EXTERNAL_ON: Final[str] = "mic_external_on"
    MIC_NONE: Final[str] = "mic_none"
    MIC_OFF: Final[str] = "mic_off"
    MICROWAVE: Final[str] = "microwave"
    MILITARY_TECH: Final[str] = "military_tech"
    MINIMIZE: Final[str] = "minimize"
    MINOR_CRASH: Final[str] = "minor_crash"
    MISCELLANEOUS_SERVICES: Final[str] = "miscellaneous_services"
    MISSED_VIDEO_CALL: Final[str] = "missed_video_call"
    MMS: Final[str] = "mms"
    MOBILE_FRIENDLY: Final[str] = "mobile_friendly"
    MOBILE_OFF: Final[str] = "mobile_off"
    MOBILE_SCREEN_SHARE: Final[str] = "mobile_screen_share"
    MOBILEDATA_OFF: Final[str] = "mobiledata_off"
    MODE: Final[str] = "mode"
    MODE_COMMENT: Final[str] = "mode_comment"
    MODE_EDIT: Final[str] = "mode_edit"
    MODE_EDIT_OUTLINE: Final[str] = "mode_edit_outline"
    MODE_FAN_OFF: Final[str] = "mode_fan_off"
    MODE_NIGHT: Final[str] = "mode_night"
    MODE_OF_TRAVEL: Final[str] = "mode_of_travel"
    MODE_STANDBY: Final[str] = "mode_standby"
    MODEL_TRAINING: Final[str] = "model_training"
    MONETIZATION_ON: Final[str] = "monetization_on"
    MONEY: Final[str] = "money"
    MONEY_OFF: Final[str] = "money_off"
    MONEY_OFF_CSRED: Final[str] = "money_off_csred"
    MONITOR: Final[str] = "monitor"
    MONITOR_HEART: Final[str] = "monitor_heart"
    MONITOR_WEIGHT: Final[str] = "monitor_weight"
    MONOCHROME_PHOTOS: Final[str] = "monochrome_photos"
    MOOD: Final[str] = "mood"
    MOOD_BAD: Final[str] = "mood_bad"
    MOPED: Final[str] = "moped"
    MORE: Final[str] = "more"
    MORE_HORIZ: Final[str] = "more_horiz"
    MORE_TIME: Final[str] = "more_time"
    MORE_VERT: Final[str] = "more_vert"
    MOSQUE: Final[str] = "mosque"
    MOTION_PHOTOS_AUTO: Final[str] = "motion_photos_auto"
    MOTION_PHOTOS_OFF: Final[str] = "motion_photos_off"
    MOTION_PHOTOS_ON: Final[str] = "motion_photos_on"
    MOTION_PHOTOS_PAUSE: Final[str] = "motion_photos_pause"
    MOTION_PHOTOS_PAUSED: Final[str] = "motion_photos_paused"
    MOTORCYCLE: Final[str] = "motorcycle"
    MOUSE: Final[str] = "mouse"
    MOVE_DOWN: Final[str] = "move_down"
    MOVE_TO_INBOX: Final[str] = "move_to_inbox"
    MOVE_UP: Final[str] = "move_up"
    MOVIE: Final[str] = "movie"
    MOVIE_CREATION: Final[str] = "movie_creation"
    MOVIE_EDIT: Final[str] = "movie_edit"
    MOVIE_FILTER: Final[str] = "movie_filter"
    MOVING: Final[str] = "moving"
    MP: Final[str] = "mp"
    MULTILINE_CHART: Final[str] = "multiline_chart"
    MULTIPLE_STOP: Final[str] = "multiple_stop"
    MULTITRACK_AUDIO: Final[str] = "multitrack_audio"
    MUSEUM: Final[str] = "museum"
    MUSIC_NOTE: Final[str] = "music_note"
    MUSIC_OFF: Final[str] = "music_off"
    MUSIC_VIDEO: Final[str] = "music_video"
    MY_LIBRARY_ADD: Final[str] = "my_library_add"
    MY_LIBRARY_BOOKS: Final[str] = "my_library_books"
    MY_LIBRARY_MUSIC: Final[str] = "my_library_music"
    MY_LOCATION: Final[str] = "my_location"
    NAT: Final[str] = "nat"
    NATURE: Final[str] = "nature"
    NATURE_PEOPLE: Final[str] = "nature_people"
    NAVIGATE_BEFORE: Final[str] = "navigate_before"
    NAVIGATE_NEXT: Final[str] = "navigate_next"
    NAVIGATION: Final[str] = "navigation"
    NEAR_ME: Final[str] = "near_me"
    NEAR_ME_DISABLED: Final[str] = "near_me_disabled"
    NEARBY_ERROR: Final[str] = "nearby_error"
    NEARBY_OFF: Final[str] = "nearby_off"
    NEST_CAM_WIRED_STAND: Final[str] = "nest_cam_wired_stand"
    NETWORK_CELL: Final[str] = "network_cell"
    NETWORK_CHECK: Final[str] = "network_check"
    NETWORK_LOCKED: Final[str] = "network_locked"
    NETWORK_PING: Final[str] = "network_ping"
    NETWORK_WIFI: Final[str] = "network_wifi"
    NETWORK_WIFI_1_BAR: Final[str] = "network_wifi_1_bar"
    NETWORK_WIFI_2_BAR: Final[str] = "network_wifi_2_bar"
    NETWORK_WIFI_3_BAR: Final[str] = "network_wifi_3_bar"
    NEW_LABEL: Final[str] = "new_label"
    NEW_RELEASES: Final[str] = "new_releases"
    NEWSPAPER: Final[str] = "newspaper"
    NEXT_PLAN: Final[str] = "next_plan"
    NEXT_WEEK: Final[str] = "next_week"
    NFC: Final[str] = "nfc"
    NIGHT_SHELTER: Final[str] = "night_shelter"
    NIGHTLIFE: Final[str] = "nightlife"
    NIGHTLIGHT: Final[str] = "nightlight"
    NIGHTLIGHT_ROUND: Final[str] = "nightlight_round"
    NIGHTS_STAY: Final[str] = "nights_stay"
    NO_ACCOUNTS: Final[str] = "no_accounts"
    NO_ADULT_CONTENT: Final[str] = "no_adult_content"
    NO_BACKPACK: Final[str] = "no_backpack"
    NO_CELL: Final[str] = "no_cell"
    NO_CRASH: Final[str] = "no_crash"
    NO_DRINKS: Final[str] = "no_drinks"
    NO_ENCRYPTION: Final[str] = "no_encryption"
    NO_ENCRYPTION_GMAILERRORRED: Final[str] = "no_encryption_gmailerrorred"
    NO_FLASH: Final[str] = "no_flash"
    NO_FOOD: Final[str] = "no_food"
    NO_LUGGAGE: Final[str] = "no_luggage"
    NO_MEALS: Final[str] = "no_meals"
    NO_MEALS_OULINE: Final[str] = "no_meals_ouline"
    NO_MEETING_ROOM: Final[str] = "no_meeting_room"
    NO_PHOTOGRAPHY: Final[str] = "no_photography"
    NO_SIM: Final[str] = "no_sim"
    NO_STROLLER: Final[str] = "no_stroller"
    NO_TRANSFER: Final[str] = "no_transfer"
    NOISE_AWARE: Final[str] = "noise_aware"
    NOISE_CONTROL_OFF: Final[str] = "noise_control_off"
    NORDIC_WALKING: Final[str] = "nordic_walking"
    NORTH: Final[str] = "north"
    NORTH_EAST: Final[str] = "north_east"
    NORTH_WEST: Final[str] = "north_west"
    NOT_ACCESSIBLE: Final[str] = "not_accessible"
    NOT_INTERESTED: Final[str] = "not_interested"
    NOT_LISTED_LOCATION: Final[str] = "not_listed_location"
    NOT_STARTED: Final[str] = "not_started"
    NOTE: Final[str] = "note"
    NOTE_ADD: Final[str] = "note_add"
    NOTE_ALT: Final[str] = "note_alt"
    NOTES: Final[str] = "notes"
    NOTIFICATION_ADD: Final[str] = "notification_add"
    NOTIFICATION_IMPORTANT: Final[str] = "notification_important"
    NOTIFICATIONS: Final[str] = "notifications"
    NOTIFICATIONS_ACTIVE: Final[str] = "notifications_active"
    NOTIFICATIONS_NONE: Final[str] = "notifications_none"
    NOTIFICATIONS_OFF: Final[str] = "notifications_off"
    NOTIFICATIONS_ON: Final[str] = "notifications_on"
    NOTIFICATIONS_PAUSED: Final[str] = "notifications_paused"
    NOW_WALLPAPER: Final[str] = "now_wallpaper"
    NOW_WIDGETS: Final[str] = "now_widgets"
    NUMBERS: Final[str] = "numbers"
    OFFLINE_BOLT: Final[str] = "offline_bolt"
    OFFLINE_PIN: Final[str] = "offline_pin"
    OFFLINE_SHARE: Final[str] = "offline_share"
    OIL_BARREL: Final[str] = "oil_barrel"
    ON_DEVICE_TRAINING: Final[str] = "on_device_training"
    ONDEMAND_VIDEO: Final[str] = "ondemand_video"
    ONLINE_PREDICTION: Final[str] = "online_prediction"
    OPACITY: Final[str] = "opacity"
    OPEN_IN_BROWSER: Final[str] = "open_in_browser"
    OPEN_IN_FULL: Final[str] = "open_in_full"
    OPEN_IN_NEW: Final[str] = "open_in_new"
    OPEN_IN_NEW_OFF: Final[str] = "open_in_new_off"
    OPEN_WITH: Final[str] = "open_with"
    OTHER_HOUSES: Final[str] = "other_houses"
    OUTBOND: Final[str] = "outbond"
    OUTBOUND: Final[str] = "outbound"
    OUTBOX: Final[str] = "outbox"
    OUTDOOR_GRILL: Final[str] = "outdoor_grill"
    OUTGOING_MAIL: Final[str] = "outgoing_mail"
    OUTLET: Final[str] = "outlet"
    OUTLINED_FLAG: Final[str] = "outlined_flag"
    OUTPUT: Final[str] = "output"
    PADDING: Final[str] = "padding"
    PAGES: Final[str] = "pages"
    PAGEVIEW: Final[str] = "pageview"
    PAID: Final[str] = "paid"
    PALETTE: Final[str] = "palette"
    PALLET: Final[str] = "pallet"
    PAN_TOOL: Final[str] = "pan_tool"
    PAN_TOOL_ALT: Final[str] = "pan_tool_alt"
    PANORAMA: Final[str] = "panorama"
    PANORAMA_FISH_EYE: Final[str] = "panorama_fish_eye"
    PANORAMA_FISHEYE: Final[str] = "panorama_fisheye"
    PANORAMA_HORIZONTAL: Final[str] = "panorama_horizontal"
    PANORAMA_HORIZONTAL_SELECT: Final[str] = "panorama_horizontal_select"
    PANORAMA_PHOTOSPHERE: Final[str] = "panorama_photosphere"
    PANORAMA_PHOTOSPHERE_SELECT: Final[str] = "panorama_photosphere_select"
    PANORAMA_VERTICAL: Final[str] = "panorama_vertical"
    PANORAMA_VERTICAL_SELECT: Final[str] = "panorama_vertical_select"
    PANORAMA_WIDE_ANGLE: Final[str] = "panorama_wide_angle"
    PANORAMA_WIDE_ANGLE_SELECT: Final[str] = "panorama_wide_angle_select"
    PARAGLIDING: Final[str] = "paragliding"
    PARK: Final[str] = "park"
    PARTY_MODE: Final[str] = "party_mode"
    PASSWORD: Final[str] = "password"
    PATTERN: Final[str] = "pattern"
    PAUSE: Final[str] = "pause"
    PAUSE_CIRCLE: Final[str] = "pause_circle"
    PAUSE_CIRCLE_FILLED: Final[str] = "pause_circle_filled"
    PAUSE_CIRCLE_OUTLINE: Final[str] = "pause_circle_outline"
    PAUSE_PRESENTATION: Final[str] = "pause_presentation"
    PAYMENT: Final[str] = "payment"
    PAYMENTS: Final[str] = "payments"
    PAYPAL: Final[str] = "paypal"
    PEDAL_BIKE: Final[str] = "pedal_bike"
    PENDING: Final[str] = "pending"
    PENDING_ACTIONS: Final[str] = "pending_actions"
    PENTAGON: Final[str] = "pentagon"
    PEOPLE: Final[str] = "people"
    PEOPLE_ALT: Final[str] = "people_alt"
    PEOPLE_OUTLINE: Final[str] = "people_outline"
    PERCENT: Final[str] = "percent"
    PERM_CAMERA_MIC: Final[str] = "perm_camera_mic"
    PERM_CONTACT_CAL: Final[str] = "perm_contact_cal"
    PERM_CONTACT_CALENDAR: Final[str] = "perm_contact_calendar"
    PERM_DATA_SETTING: Final[str] = "perm_data_setting"
    PERM_DEVICE_INFO: Final[str] = "perm_device_info"
    PERM_DEVICE_INFORMATION: Final[str] = "perm_device_information"
    PERM_IDENTITY: Final[str] = "perm_identity"
    PERM_MEDIA: Final[str] = "perm_media"
    PERM_PHONE_MSG: Final[str] = "perm_phone_msg"
    PERM_SCAN_WIFI: Final[str] = "perm_scan_wifi"
    PERSON: Final[str] = "person"
    PERSON_2: Final[str] = "person_2"
    PERSON_3: Final[str] = "person_3"
    PERSON_4: Final[str] = "person_4"
    PERSON_ADD: Final[str] = "person_add"
    PERSON_ADD_ALT: Final[str] = "person_add_alt"
    PERSON_ADD_ALT_1: Final[str] = "person_add_alt_1"
    PERSON_ADD_DISABLED: Final[str] = "person_add_disabled"
    PERSON_OFF: Final[str] = "person_off"
    PERSON_OUTLINE: Final[str] = "person_outline"
    PERSON_PIN: Final[str] = "person_pin"
    PERSON_PIN_CIRCLE: Final[str] = "person_pin_circle"
    PERSON_REMOVE: Final[str] = "person_remove"
    PERSON_REMOVE_ALT_1: Final[str] = "person_remove_alt_1"
    PERSON_SEARCH: Final[str] = "person_search"
    PERSONAL_INJURY: Final[str] = "personal_injury"
    PERSONAL_VIDEO: Final[str] = "personal_video"
    PEST_CONTROL: Final[str] = "pest_control"
    PEST_CONTROL_RODENT: Final[str] = "pest_control_rodent"
    PETS: Final[str] = "pets"
    PHISHING: Final[str] = "phishing"
    PHONE: Final[str] = "phone"
    PHONE_ANDROID: Final[str] = "phone_android"
    PHONE_BLUETOOTH_SPEAKER: Final[str] = "phone_bluetooth_speaker"
    PHONE_CALLBACK: Final[str] = "phone_callback"
    PHONE_DISABLED: Final[str] = "phone_disabled"
    PHONE_ENABLED: Final[str] = "phone_enabled"
    PHONE_FORWARDED: Final[str] = "phone_forwarded"
    PHONE_IN_TALK: Final[str] = "phone_in_talk"
    PHONE_IPHONE: Final[str] = "phone_iphone"
    PHONE_LOCKED: Final[str] = "phone_locked"
    PHONE_MISSED: Final[str] = "phone_missed"
    PHONE_PAUSED: Final[str] = "phone_paused"
    PHONELINK: Final[str] = "phonelink"
    PHONELINK_ERASE: Final[str] = "phonelink_erase"
    PHONELINK_LOCK: Final[str] = "phonelink_lock"
    PHONELINK_OFF: Final[str] = "phonelink_off"
    PHONELINK_RING: Final[str] = "phonelink_ring"
    PHONELINK_SETUP: Final[str] = "phonelink_setup"
    PHOTO: Final[str] = "photo"
    PHOTO_ALBUM: Final[str] = "photo_album"
    PHOTO_CAMERA: Final[str] = "photo_camera"
    PHOTO_CAMERA_BACK: Final[str] = "photo_camera_back"
    PHOTO_CAMERA_FRONT: Final[str] = "photo_camera_front"
    PHOTO_FILTER: Final[str] = "photo_filter"
    PHOTO_LIBRARY: Final[str] = "photo_library"
    PHOTO_SIZE_SELECT_ACTUAL: Final[str] = "photo_size_select_actual"
    PHOTO_SIZE_SELECT_LARGE: Final[str] = "photo_size_select_large"
    PHOTO_SIZE_SELECT_SMALL: Final[str] = "photo_size_select_small"
    PHP: Final[str] = "php"
    PIANO: Final[str] = "piano"
    PIANO_OFF: Final[str] = "piano_off"
    PICTURE_AS_PDF: Final[str] = "picture_as_pdf"
    PICTURE_IN_PICTURE: Final[str] = "picture_in_picture"
    PICTURE_IN_PICTURE_ALT: Final[str] = "picture_in_picture_alt"
    PIE_CHART: Final[str] = "pie_chart"
    PIE_CHART_OUTLINE: Final[str] = "pie_chart_outline"
    PIE_CHART_OUTLINED: Final[str] = "pie_chart_outlined"
    PIN: Final[str] = "pin"
    PIN_DROP: Final[str] = "pin_drop"
    PIN_END: Final[str] = "pin_end"
    PIN_INVOKE: Final[str] = "pin_invoke"
    PINCH: Final[str] = "pinch"
    PIVOT_TABLE_CHART: Final[str] = "pivot_table_chart"
    PIX: Final[str] = "pix"
    PLACE: Final[str] = "place"
    PLAGIARISM: Final[str] = "plagiarism"
    PLAY_ARROW: Final[str] = "play_arrow"
    PLAY_CIRCLE: Final[str] = "play_circle"
    PLAY_CIRCLE_FILL: Final[str] = "play_circle_fill"
    PLAY_CIRCLE_FILLED: Final[str] = "play_circle_filled"
    PLAY_CIRCLE_OUTLINE: Final[str] = "play_circle_outline"
    PLAY_DISABLED: Final[str] = "play_disabled"
    PLAY_FOR_WORK: Final[str] = "play_for_work"
    PLAY_LESSON: Final[str] = "play_lesson"
    PLAYLIST_ADD: Final[str] = "playlist_add"
    PLAYLIST_ADD_CHECK: Final[str] = "playlist_add_check"
    PLAYLIST_ADD_CHECK_CIRCLE: Final[str] = "playlist_add_check_circle"
    PLAYLIST_ADD_CIRCLE: Final[str] = "playlist_add_circle"
    PLAYLIST_PLAY: Final[str] = "playlist_play"
    PLAYLIST_REMOVE: Final[str] = "playlist_remove"
    PLUMBING: Final[str] = "plumbing"
    PLUS_ONE: Final[str] = "plus_one"
    PODCASTS: Final[str] = "podcasts"
    POINT_OF_SALE: Final[str] = "point_of_sale"
    POLICY: Final[str] = "policy"
    POLL: Final[str] = "poll"
    POLYLINE: Final[str] = "polyline"
    POLYMER: Final[str] = "polymer"
    POOL: Final[str] = "pool"
    PORTABLE_WIFI_OFF: Final[str] = "portable_wifi_off"
    PORTRAIT: Final[str] = "portrait"
    POST_ADD: Final[str] = "post_add"
    POWER: Final[str] = "power"
    POWER_INPUT: Final[str] = "power_input"
    POWER_OFF: Final[str] = "power_off"
    POWER_SETTINGS_NEW: Final[str] = "power_settings_new"
    PRECISION_MANUFACTURING: Final[str] = "precision_manufacturing"
    PREGNANT_WOMAN: Final[str] = "pregnant_woman"
    PRESENT_TO_ALL: Final[str] = "present_to_all"
    PREVIEW: Final[str] = "preview"
    PRICE_CHANGE: Final[str] = "price_change"
    PRICE_CHECK: Final[str] = "price_check"
    PRINT: Final[str] = "print"
    PRINT_DISABLED: Final[str] = "print_disabled"
    PRIORITY_HIGH: Final[str] = "priority_high"
    PRIVACY_TIP: Final[str] = "privacy_tip"
    PRIVATE_CONNECTIVITY: Final[str] = "private_connectivity"
    PRODUCTION_QUANTITY_LIMITS: Final[str] = "production_quantity_limits"
    PROPANE: Final[str] = "propane"
    PROPANE_TANK: Final[str] = "propane_tank"
    PSYCHOLOGY: Final[str] = "psychology"
    PSYCHOLOGY_ALT: Final[str] = "psychology_alt"
    PUBLIC: Final[str] = "public"
    PUBLIC_OFF: Final[str] = "public_off"
    PUBLISH: Final[str] = "publish"
    PUBLISHED_WITH_CHANGES: Final[str] = "published_with_changes"
    PUNCH_CLOCK: Final[str] = "punch_clock"
    PUSH_PIN: Final[str] = "push_pin"
    QR_CODE: Final[str] = "qr_code"
    QR_CODE_2: Final[str] = "qr_code_2"
    QR_CODE_SCANNER: Final[str] = "qr_code_scanner"
    QUERY_BUILDER: Final[str] = "query_builder"
    QUERY_STATS: Final[str] = "query_stats"
    QUESTION_ANSWER: Final[str] = "question_answer"
    QUESTION_MARK: Final[str] = "question_mark"
    QUEUE: Final[str] = "queue"
    QUEUE_MUSIC: Final[str] = "queue_music"
    QUEUE_PLAY_NEXT: Final[str] = "queue_play_next"
    QUICK_CONTACTS_DIALER: Final[str] = "quick_contacts_dialer"
    QUICK_CONTACTS_MAIL: Final[str] = "quick_contacts_mail"
    QUICKREPLY: Final[str] = "quickreply"
    QUIZ: Final[str] = "quiz"
    QUORA: Final[str] = "quora"
    R_MOBILEDATA: Final[str] = "r_mobiledata"
    RADAR: Final[str] = "radar"
    RADIO: Final[str] = "radio"
    RADIO_BUTTON_CHECKED: Final[str] = "radio_button_checked"
    RADIO_BUTTON_OFF: Final[str] = "radio_button_off"
    RADIO_BUTTON_ON: Final[str] = "radio_button_on"
    RADIO_BUTTON_UNCHECKED: Final[str] = "radio_button_unchecked"
    RAILWAY_ALERT: Final[str] = "railway_alert"
    RAMEN_DINING: Final[str] = "ramen_dining"
    RAMP_LEFT: Final[str] = "ramp_left"
    RAMP_RIGHT: Final[str] = "ramp_right"
    RATE_REVIEW: Final[str] = "rate_review"
    RAW_OFF: Final[str] = "raw_off"
    RAW_ON: Final[str] = "raw_on"
    READ_MORE: Final[str] = "read_more"
    REAL_ESTATE_AGENT: Final[str] = "real_estate_agent"
    REBASE_EDIT: Final[str] = "rebase_edit"
    RECEIPT: Final[str] = "receipt"
    RECEIPT_LONG: Final[str] = "receipt_long"
    RECENT_ACTORS: Final[str] = "recent_actors"
    RECOMMEND: Final[str] = "recommend"
    RECORD_VOICE_OVER: Final[str] = "record_voice_over"
    RECTANGLE: Final[str] = "rectangle"
    RECYCLING: Final[str] = "recycling"
    REDDIT: Final[str] = "reddit"
    REDEEM: Final[str] = "redeem"
    REDO: Final[str] = "redo"
    REDUCE_CAPACITY: Final[str] = "reduce_capacity"
    REFRESH: Final[str] = "refresh"
    REMEMBER_ME: Final[str] = "remember_me"
    REMOVE: Final[str] = "remove"
    REMOVE_CIRCLE: Final[str] = "remove_circle"
    REMOVE_CIRCLE_OUTLINE: Final[str] = "remove_circle_outline"
    REMOVE_DONE: Final[str] = "remove_done"
    REMOVE_FROM_QUEUE: Final[str] = "remove_from_queue"
    REMOVE_MODERATOR: Final[str] = "remove_moderator"
    REMOVE_RED_EYE: Final[str] = "remove_red_eye"
    REMOVE_ROAD: Final[str] = "remove_road"
    REMOVE_SHOPPING_CART: Final[str] = "remove_shopping_cart"
    REORDER: Final[str] = "reorder"
    REPARTITION: Final[str] = "repartition"
    REPEAT: Final[str] = "repeat"
    REPEAT_ON: Final[str] = "repeat_on"
    REPEAT_ONE: Final[str] = "repeat_one"
    REPEAT_ONE_ON: Final[str] = "repeat_one_on"
    REPLAY: Final[str] = "replay"
    REPLAY_10: Final[str] = "replay_10"
    REPLAY_30: Final[str] = "replay_30"
    REPLAY_5: Final[str] = "replay_5"
    REPLAY_CIRCLE_FILLED: Final[str] = "replay_circle_filled"
    REPLY: Final[str] = "reply"
    REPLY_ALL: Final[str] = "reply_all"
    REPORT: Final[str] = "report"
    REPORT_GMAILERRORRED: Final[str] = "report_gmailerrorred"
    REPORT_OFF: Final[str] = "report_off"
    REPORT_PROBLEM: Final[str] = "report_problem"
    REQUEST_PAGE: Final[str] = "request_page"
    REQUEST_QUOTE: Final[str] = "request_quote"
    RESET_TV: Final[str] = "reset_tv"
    RESTART_ALT: Final[str] = "restart_alt"
    RESTAURANT: Final[str] = "restaurant"
    RESTAURANT_MENU: Final[str] = "restaurant_menu"
    RESTORE: Final[str] = "restore"
    RESTORE_FROM_TRASH: Final[str] = "restore_from_trash"
    RESTORE_PAGE: Final[str] = "restore_page"
    REVIEWS: Final[str] = "reviews"
    RICE_BOWL: Final[str] = "rice_bowl"
    RING_VOLUME: Final[str] = "ring_volume"
    ROCKET: Final[str] = "rocket"
    ROCKET_LAUNCH: Final[str] = "rocket_launch"
    ROLLER_SHADES: Final[str] = "roller_shades"
    ROLLER_SHADES_CLOSED: Final[str] = "roller_shades_closed"
    ROLLER_SKATING: Final[str] = "roller_skating"
    ROOFING: Final[str] = "roofing"
    ROOM: Final[str] = "room"
    ROOM_PREFERENCES: Final[str] = "room_preferences"
    ROOM_SERVICE: Final[str] = "room_service"
    ROTATE_90_DEGREES_CCW: Final[str] = "rotate_90_degrees_ccw"
    ROTATE_90_DEGREES_CW: Final[str] = "rotate_90_degrees_cw"
    ROTATE_LEFT: Final[str] = "rotate_left"
    ROTATE_RIGHT: Final[str] = "rotate_right"
    ROUNDABOUT_LEFT: Final[str] = "roundabout_left"
    ROUNDABOUT_RIGHT: Final[str] = "roundabout_right"
    ROUNDED_CORNER: Final[str] = "rounded_corner"
    ROUTE: Final[str] = "route"
    ROUTER: Final[str] = "router"
    ROWING: Final[str] = "rowing"
    RSS_FEED: Final[str] = "rss_feed"
    RSVP: Final[str] = "rsvp"
    RTT: Final[str] = "rtt"
    RULE: Final[str] = "rule"
    RULE_FOLDER: Final[str] = "rule_folder"
    RUN_CIRCLE: Final[str] = "run_circle"
    RUNNING_WITH_ERRORS: Final[str] = "running_with_errors"
    RV_HOOKUP: Final[str] = "rv_hookup"
    SAFETY_CHECK: Final[str] = "safety_check"
    SAFETY_DIVIDER: Final[str] = "safety_divider"
    SAILING: Final[str] = "sailing"
    SANITIZER: Final[str] = "sanitizer"
    SATELLITE: Final[str] = "satellite"
    SATELLITE_ALT: Final[str] = "satellite_alt"
    SAVE: Final[str] = "save"
    SAVE_ALT: Final[str] = "save_alt"
    SAVE_AS: Final[str] = "save_as"
    SAVED_SEARCH: Final[str] = "saved_search"
    SAVINGS: Final[str] = "savings"
    SCALE: Final[str] = "scale"
    SCANNER: Final[str] = "scanner"
    SCATTER_PLOT: Final[str] = "scatter_plot"
    SCHEDULE: Final[str] = "schedule"
    SCHEDULE_SEND: Final[str] = "schedule_send"
    SCHEMA: Final[str] = "schema"
    SCHOOL: Final[str] = "school"
    SCIENCE: Final[str] = "science"
    SCORE: Final[str] = "score"
    SCOREBOARD: Final[str] = "scoreboard"
    SCREEN_LOCK_LANDSCAPE: Final[str] = "screen_lock_landscape"
    SCREEN_LOCK_PORTRAIT: Final[str] = "screen_lock_portrait"
    SCREEN_LOCK_ROTATION: Final[str] = "screen_lock_rotation"
    SCREEN_ROTATION: Final[str] = "screen_rotation"
    SCREEN_ROTATION_ALT: Final[str] = "screen_rotation_alt"
    SCREEN_SEARCH_DESKTOP: Final[str] = "screen_search_desktop"
    SCREEN_SHARE: Final[str] = "screen_share"
    SCREENSHOT: Final[str] = "screenshot"
    SCREENSHOT_MONITOR: Final[str] = "screenshot_monitor"
    SCUBA_DIVING: Final[str] = "scuba_diving"
    SD: Final[str] = "sd"
    SD_CARD: Final[str] = "sd_card"
    SD_CARD_ALERT: Final[str] = "sd_card_alert"
    SD_STORAGE: Final[str] = "sd_storage"
    SEARCH: Final[str] = "search"
    SEARCH_OFF: Final[str] = "search_off"
    SECURITY: Final[str] = "security"
    SECURITY_UPDATE: Final[str] = "security_update"
    SECURITY_UPDATE_GOOD: Final[str] = "security_update_good"
    SECURITY_UPDATE_WARNING: Final[str] = "security_update_warning"
    SEGMENT: Final[str] = "segment"
    SELECT_ALL: Final[str] = "select_all"
    SELF_IMPROVEMENT: Final[str] = "self_improvement"
    SELL: Final[str] = "sell"
    SEND: Final[str] = "send"
    SEND_AND_ARCHIVE: Final[str] = "send_and_archive"
    SEND_TIME_EXTENSION: Final[str] = "send_time_extension"
    SEND_TO_MOBILE: Final[str] = "send_to_mobile"
    SENSOR_DOOR: Final[str] = "sensor_door"
    SENSOR_OCCUPIED: Final[str] = "sensor_occupied"
    SENSOR_WINDOW: Final[str] = "sensor_window"
    SENSORS: Final[str] = "sensors"
    SENSORS_OFF: Final[str] = "sensors_off"
    SENTIMENT_DISSATISFIED: Final[str] = "sentiment_dissatisfied"
    SENTIMENT_NEUTRAL: Final[str] = "sentiment_neutral"
    SENTIMENT_SATISFIED: Final[str] = "sentiment_satisfied"
    SENTIMENT_SATISFIED_ALT: Final[str] = "sentiment_satisfied_alt"
    SENTIMENT_VERY_DISSATISFIED: Final[str] = "sentiment_very_dissatisfied"
    SENTIMENT_VERY_SATISFIED: Final[str] = "sentiment_very_satisfied"
    SET_MEAL: Final[str] = "set_meal"
    SETTINGS: Final[str] = "settings"
    SETTINGS_ACCESSIBILITY: Final[str] = "settings_accessibility"
    SETTINGS_APPLICATIONS: Final[str] = "settings_applications"
    SETTINGS_BACKUP_RESTORE: Final[str] = "settings_backup_restore"
    SETTINGS_BLUETOOTH: Final[str] = "settings_bluetooth"
    SETTINGS_BRIGHTNESS: Final[str] = "settings_brightness"
    SETTINGS_CELL: Final[str] = "settings_cell"
    SETTINGS_DISPLAY: Final[str] = "settings_display"
    SETTINGS_ETHERNET: Final[str] = "settings_ethernet"
    SETTINGS_INPUT_ANTENNA: Final[str] = "settings_input_antenna"
    SETTINGS_INPUT_COMPONENT: Final[str] = "settings_input_component"
    SETTINGS_INPUT_COMPOSITE: Final[str] = "settings_input_composite"
    SETTINGS_INPUT_HDMI: Final[str] = "settings_input_hdmi"
    SETTINGS_INPUT_SVIDEO: Final[str] = "settings_input_svideo"
    SETTINGS_OVERSCAN: Final[str] = "settings_overscan"
    SETTINGS_PHONE: Final[str] = "settings_phone"
    SETTINGS_POWER: Final[str] = "settings_power"
    SETTINGS_REMOTE: Final[str] = "settings_remote"
    SETTINGS_SUGGEST: Final[str] = "settings_suggest"
    SETTINGS_SYSTEM_DAYDREAM: Final[str] = "settings_system_daydream"
    SETTINGS_VOICE: Final[str] = "settings_voice"
    SEVERE_COLD: Final[str] = "severe_cold"
    SHAPE_LINE: Final[str] = "shape_line"
    SHARE: Final[str] = "share"
    SHARE_ARRIVAL_TIME: Final[str] = "share_arrival_time"
    SHARE_LOCATION: Final[str] = "share_location"
    SHELVES: Final[str] = "shelves"
    SHIELD: Final[str] = "shield"
    SHIELD_MOON: Final[str] = "shield_moon"
    SHOP: Final[str] = "shop"
    SHOP_2: Final[str] = "shop_2"
    SHOP_TWO: Final[str] = "shop_two"
    SHOPIFY: Final[str] = "shopify"
    SHOPPING_BAG: Final[str] = "shopping_bag"
    SHOPPING_BASKET: Final[str] = "shopping_basket"
    SHOPPING_CART: Final[str] = "shopping_cart"
    SHOPPING_CART_CHECKOUT: Final[str] = "shopping_cart_checkout"
    SHORT_TEXT: Final[str] = "short_text"
    SHORTCUT: Final[str] = "shortcut"
    SHOW_CHART: Final[str] = "show_chart"
    SHOWER: Final[str] = "shower"
    SHUFFLE: Final[str] = "shuffle"
    SHUFFLE_ON: Final[str] = "shuffle_on"
    SHUTTER_SPEED: Final[str] = "shutter_speed"
    SICK: Final[str] = "sick"
    SIGN_LANGUAGE: Final[str] = "sign_language"
    SIGNAL_CELLULAR_0_BAR: Final[str] = "signal_cellular_0_bar"
    SIGNAL_CELLULAR_4_BAR: Final[str] = "signal_cellular_4_bar"
    SIGNAL_CELLULAR_ALT: Final[str] = "signal_cellular_alt"
    SIGNAL_CELLULAR_ALT_1_BAR: Final[str] = "signal_cellular_alt_1_bar"
    SIGNAL_CELLULAR_ALT_2_BAR: Final[str] = "signal_cellular_alt_2_bar"
    SIGNAL_CELLULAR_CONNECTED_NO_INTERNET_0_BAR: Final[str] = "signal_cellular_connected_no_internet_0_bar"
    SIGNAL_CELLULAR_CONNECTED_NO_INTERNET_4_BAR: Final[str] = "signal_cellular_connected_no_internet_4_bar"
    SIGNAL_CELLULAR_NO_SIM: Final[str] = "signal_cellular_no_sim"
    SIGNAL_CELLULAR_NODATA: Final[str] = "signal_cellular_nodata"
    SIGNAL_CELLULAR_NULL: Final[str] = "signal_cellular_null"
    SIGNAL_CELLULAR_OFF: Final[str] = "signal_cellular_off"
    SIGNAL_WIFI_0_BAR: Final[str] = "signal_wifi_0_bar"
    SIGNAL_WIFI_4_BAR: Final[str] = "signal_wifi_4_bar"
    SIGNAL_WIFI_4_BAR_LOCK: Final[str] = "signal_wifi_4_bar_lock"
    SIGNAL_WIFI_BAD: Final[str] = "signal_wifi_bad"
    SIGNAL_WIFI_CONNECTED_NO_INTERNET_4: Final[str] = "signal_wifi_connected_no_internet_4"
    SIGNAL_WIFI_OFF: Final[str] = "signal_wifi_off"
    SIGNAL_WIFI_STATUSBAR_4_BAR: Final[str] = "signal_wifi_statusbar_4_bar"
    SIGNAL_WIFI_STATUSBAR_CONNECTED_NO_INTERNET_4: Final[str] = "signal_wifi_statusbar_connected_no_internet_4"
    SIGNAL_WIFI_STATUSBAR_NULL: Final[str] = "signal_wifi_statusbar_null"
    SIGNPOST: Final[str] = "signpost"
    SIM_CARD: Final[str] = "sim_card"
    SIM_CARD_ALERT: Final[str] = "sim_card_alert"
    SIM_CARD_DOWNLOAD: Final[str] = "sim_card_download"
    SINGLE_BED: Final[str] = "single_bed"
    SIP: Final[str] = "sip"
    SKATEBOARDING: Final[str] = "skateboarding"
    SKIP_NEXT: Final[str] = "skip_next"
    SKIP_PREVIOUS: Final[str] = "skip_previous"
    SLEDDING: Final[str] = "sledding"
    SLIDESHOW: Final[str] = "slideshow"
    SLOW_MOTION_VIDEO: Final[str] = "slow_motion_video"
    SMART_BUTTON: Final[str] = "smart_button"
    SMART_DISPLAY: Final[str] = "smart_display"
    SMART_SCREEN: Final[str] = "smart_screen"
    SMART_TOY: Final[str] = "smart_toy"
    SMARTPHONE: Final[str] = "smartphone"
    SMOKE_FREE: Final[str] = "smoke_free"
    SMOKING_ROOMS: Final[str] = "smoking_rooms"
    SMS: Final[str] = "sms"
    SMS_FAILED: Final[str] = "sms_failed"
    SNAPCHAT: Final[str] = "snapchat"
    SNIPPET_FOLDER: Final[str] = "snippet_folder"
    SNOOZE: Final[str] = "snooze"
    SNOWBOARDING: Final[str] = "snowboarding"
    SNOWING: Final[str] = "snowing"
    SNOWMOBILE: Final[str] = "snowmobile"
    SNOWSHOEING: Final[str] = "snowshoeing"
    SOAP: Final[str] = "soap"
    SOCIAL_DISTANCE: Final[str] = "social_distance"
    SOLAR_POWER: Final[str] = "solar_power"
    SORT: Final[str] = "sort"
    SORT_BY_ALPHA: Final[str] = "sort_by_alpha"
    SOS: Final[str] = "sos"
    SOUP_KITCHEN: Final[str] = "soup_kitchen"
    SOURCE: Final[str] = "source"
    SOUTH: Final[str] = "south"
    SOUTH_AMERICA: Final[str] = "south_america"
    SOUTH_EAST: Final[str] = "south_east"
    SOUTH_WEST: Final[str] = "south_west"
    SPA: Final[str] = "spa"
    SPACE_BAR: Final[str] = "space_bar"
    SPACE_DASHBOARD: Final[str] = "space_dashboard"
    SPATIAL_AUDIO: Final[str] = "spatial_audio"
    SPATIAL_AUDIO_OFF: Final[str] = "spatial_audio_off"
    SPATIAL_TRACKING: Final[str] = "spatial_tracking"
    SPEAKER: Final[str] = "speaker"
    SPEAKER_GROUP: Final[str] = "speaker_group"
    SPEAKER_NOTES: Final[str] = "speaker_notes"
    SPEAKER_NOTES_OFF: Final[str] = "speaker_notes_off"
    SPEAKER_PHONE: Final[str] = "speaker_phone"
    SPEED: Final[str] = "speed"
    SPELLCHECK: Final[str] = "spellcheck"
    SPLITSCREEN: Final[str] = "splitscreen"
    SPOKE: Final[str] = "spoke"
    SPORTS: Final[str] = "sports"
    SPORTS_BAR: Final[str] = "sports_bar"
    SPORTS_BASEBALL: Final[str] = "sports_baseball"
    SPORTS_BASKETBALL: Final[str] = "sports_basketball"
    SPORTS_CRICKET: Final[str] = "sports_cricket"
    SPORTS_ESPORTS: Final[str] = "sports_esports"
    SPORTS_FOOTBALL: Final[str] = "sports_football"
    SPORTS_GOLF: Final[str] = "sports_golf"
    SPORTS_GYMNASTICS: Final[str] = "sports_gymnastics"
    SPORTS_HANDBALL: Final[str] = "sports_handball"
    SPORTS_HOCKEY: Final[str] = "sports_hockey"
    SPORTS_KABADDI: Final[str] = "sports_kabaddi"
    SPORTS_MARTIAL_ARTS: Final[str] = "sports_martial_arts"
    SPORTS_MMA: Final[str] = "sports_mma"
    SPORTS_MOTORSPORTS: Final[str] = "sports_motorsports"
    SPORTS_RUGBY: Final[str] = "sports_rugby"
    SPORTS_SCORE: Final[str] = "sports_score"
    SPORTS_SOCCER: Final[str] = "sports_soccer"
    SPORTS_TENNIS: Final[str] = "sports_tennis"
    SPORTS_VOLLEYBALL: Final[str] = "sports_volleyball"
    SQUARE: Final[str] = "square"
    SQUARE_FOOT: Final[str] = "square_foot"
    SSID_CHART: Final[str] = "ssid_chart"
    STACKED_BAR_CHART: Final[str] = "stacked_bar_chart"
    STACKED_LINE_CHART: Final[str] = "stacked_line_chart"
    STADIUM: Final[str] = "stadium"
    STAIRS: Final[str] = "stairs"
    STAR: Final[str] = "star"
    STAR_BORDER: Final[str] = "star_border"
    STAR_BORDER_PURPLE500: Final[str] = "star_border_purple500"
    STAR_HALF: Final[str] = "star_half"
    STAR_OUTLINE: Final[str] = "star_outline"
    STAR_PURPLE500: Final[str] = "star_purple500"
    STAR_RATE: Final[str] = "star_rate"
    STARS: Final[str] = "stars"
    START: Final[str] = "start"
    STAY_CURRENT_LANDSCAPE: Final[str] = "stay_current_landscape"
    STAY_CURRENT_PORTRAIT: Final[str] = "stay_current_portrait"
    STAY_PRIMARY_LANDSCAPE: Final[str] = "stay_primary_landscape"
    STAY_PRIMARY_PORTRAIT: Final[str] = "stay_primary_portrait"
    STICKY_NOTE_2: Final[str] = "sticky_note_2"
    STOP: Final[str] = "stop"
    STOP_CIRCLE: Final[str] = "stop_circle"
    STOP_SCREEN_SHARE: Final[str] = "stop_screen_share"
    STORAGE: Final[str] = "storage"
    STORE: Final[str] = "store"
    STORE_MALL_DIRECTORY: Final[str] = "store_mall_directory"
    STOREFRONT: Final[str] = "storefront"
    STORM: Final[str] = "storm"
    STRAIGHT: Final[str] = "straight"
    STRAIGHTEN: Final[str] = "straighten"
    STREAM: Final[str] = "stream"
    STREETVIEW: Final[str] = "streetview"
    STRIKETHROUGH_S: Final[str] = "strikethrough_s"
    STROLLER: Final[str] = "stroller"
    STYLE: Final[str] = "style"
    SUBDIRECTORY_ARROW_LEFT: Final[str] = "subdirectory_arrow_left"
    SUBDIRECTORY_ARROW_RIGHT: Final[str] = "subdirectory_arrow_right"
    SUBJECT: Final[str] = "subject"
    SUBSCRIPT: Final[str] = "subscript"
    SUBSCRIPTIONS: Final[str] = "subscriptions"
    SUBTITLES: Final[str] = "subtitles"
    SUBTITLES_OFF: Final[str] = "subtitles_off"
    SUBWAY: Final[str] = "subway"
    SUMMARIZE: Final[str] = "summarize"
    SUNNY: Final[str] = "sunny"
    SUNNY_SNOWING: Final[str] = "sunny_snowing"
    SUPERSCRIPT: Final[str] = "superscript"
    SUPERVISED_USER_CIRCLE: Final[str] = "supervised_user_circle"
    SUPERVISOR_ACCOUNT: Final[str] = "supervisor_account"
    SUPPORT: Final[str] = "support"
    SUPPORT_AGENT: Final[str] = "support_agent"
    SURFING: Final[str] = "surfing"
    SURROUND_SOUND: Final[str] = "surround_sound"
    SWAP_CALLS: Final[str] = "swap_calls"
    SWAP_HORIZ: Final[str] = "swap_horiz"
    SWAP_HORIZONTAL_CIRCLE: Final[str] = "swap_horizontal_circle"
    SWAP_VERT: Final[str] = "swap_vert"
    SWAP_VERT_CIRCLE: Final[str] = "swap_vert_circle"
    SWAP_VERTICAL_CIRCLE: Final[str] = "swap_vertical_circle"
    SWIPE: Final[str] = "swipe"
    SWIPE_DOWN: Final[str] = "swipe_down"
    SWIPE_DOWN_ALT: Final[str] = "swipe_down_alt"
    SWIPE_LEFT: Final[str] = "swipe_left"
    SWIPE_LEFT_ALT: Final[str] = "swipe_left_alt"
    SWIPE_RIGHT: Final[str] = "swipe_right"
    SWIPE_RIGHT_ALT: Final[str] = "swipe_right_alt"
    SWIPE_UP: Final[str] = "swipe_up"
    SWIPE_UP_ALT: Final[str] = "swipe_up_alt"
    SWIPE_VERTICAL: Final[str] = "swipe_vertical"
    SWITCH_ACCESS_SHORTCUT: Final[str] = "switch_access_shortcut"
    SWITCH_ACCESS_SHORTCUT_ADD: Final[str] = "switch_access_shortcut_add"
    SWITCH_ACCOUNT: Final[str] = "switch_account"
    SWITCH_CAMERA: Final[str] = "switch_camera"
    SWITCH_LEFT: Final[str] = "switch_left"
    SWITCH_RIGHT: Final[str] = "switch_right"
    SWITCH_VIDEO: Final[str] = "switch_video"
    SYNAGOGUE: Final[str] = "synagogue"
    SYNC: Final[str] = "sync"
    SYNC_ALT: Final[str] = "sync_alt"
    SYNC_DISABLED: Final[str] = "sync_disabled"
    SYNC_LOCK: Final[str] = "sync_lock"
    SYNC_PROBLEM: Final[str] = "sync_problem"
    SYSTEM_SECURITY_UPDATE: Final[str] = "system_security_update"
    SYSTEM_SECURITY_UPDATE_GOOD: Final[str] = "system_security_update_good"
    SYSTEM_SECURITY_UPDATE_WARNING: Final[str] = "system_security_update_warning"
    SYSTEM_UPDATE: Final[str] = "system_update"
    SYSTEM_UPDATE_ALT: Final[str] = "system_update_alt"
    SYSTEM_UPDATE_TV: Final[str] = "system_update_tv"
    TAB: Final[str] = "tab"
    TAB_UNSELECTED: Final[str] = "tab_unselected"
    TABLE_BAR: Final[str] = "table_bar"
    TABLE_CHART: Final[str] = "table_chart"
    TABLE_RESTAURANT: Final[str] = "table_restaurant"
    TABLE_ROWS: Final[str] = "table_rows"
    TABLE_VIEW: Final[str] = "table_view"
    TABLET: Final[str] = "tablet"
    TABLET_ANDROID: Final[str] = "tablet_android"
    TABLET_MAC: Final[str] = "tablet_mac"
    TAG: Final[str] = "tag"
    TAG_FACES: Final[str] = "tag_faces"
    TAKEOUT_DINING: Final[str] = "takeout_dining"
    TAP_AND_PLAY: Final[str] = "tap_and_play"
    TAPAS: Final[str] = "tapas"
    TASK: Final[str] = "task"
    TASK_ALT: Final[str] = "task_alt"
    TAXI_ALERT: Final[str] = "taxi_alert"
    TELEGRAM: Final[str] = "telegram"
    TEMPLE_BUDDHIST: Final[str] = "temple_buddhist"
    TEMPLE_HINDU: Final[str] = "temple_hindu"
    TERMINAL: Final[str] = "terminal"
    TERRAIN: Final[str] = "terrain"
    TEXT_DECREASE: Final[str] = "text_decrease"
    TEXT_FIELDS: Final[str] = "text_fields"
    TEXT_FORMAT: Final[str] = "text_format"
    TEXT_INCREASE: Final[str] = "text_increase"
    TEXT_ROTATE_UP: Final[str] = "text_rotate_up"
    TEXT_ROTATE_VERTICAL: Final[str] = "text_rotate_vertical"
    TEXT_ROTATION_ANGLEDOWN: Final[str] = "text_rotation_angledown"
    TEXT_ROTATION_ANGLEUP: Final[str] = "text_rotation_angleup"
    TEXT_ROTATION_DOWN: Final[str] = "text_rotation_down"
    TEXT_ROTATION_NONE: Final[str] = "text_rotation_none"
    TEXT_SNIPPET: Final[str] = "text_snippet"
    TEXTSMS: Final[str] = "textsms"
    TEXTURE: Final[str] = "texture"
    THEATER_COMEDY: Final[str] = "theater_comedy"
    THEATERS: Final[str] = "theaters"
    THERMOSTAT: Final[str] = "thermostat"
    THERMOSTAT_AUTO: Final[str] = "thermostat_auto"
    THUMB_DOWN: Final[str] = "thumb_down"
    THUMB_DOWN_ALT: Final[str] = "thumb_down_alt"
    THUMB_DOWN_OFF_ALT: Final[str] = "thumb_down_off_alt"
    THUMB_UP: Final[str] = "thumb_up"
    THUMB_UP_ALT: Final[str] = "thumb_up_alt"
    THUMB_UP_OFF_ALT: Final[str] = "thumb_up_off_alt"
    THUMBS_UP_DOWN: Final[str] = "thumbs_up_down"
    THUNDERSTORM: Final[str] = "thunderstorm"
    TIKTOK: Final[str] = "tiktok"
    TIME_TO_LEAVE: Final[str] = "time_to_leave"
    TIMELAPSE: Final[str] = "timelapse"
    TIMELINE: Final[str] = "timeline"
    TIMER: Final[str] = "timer"
    TIMER_10: Final[str] = "timer_10"
    TIMER_10_SELECT: Final[str] = "timer_10_select"
    TIMER_3: Final[str] = "timer_3"
    TIMER_3_SELECT: Final[str] = "timer_3_select"
    TIMER_OFF: Final[str] = "timer_off"
    TIPS_AND_UPDATES: Final[str] = "tips_and_updates"
    TIRE_REPAIR: Final[str] = "tire_repair"
    TITLE: Final[str] = "title"
    TOC: Final[str] = "toc"
    TODAY: Final[str] = "today"
    TOGGLE_OFF: Final[str] = "toggle_off"
    TOGGLE_ON: Final[str] = "toggle_on"
    TOKEN: Final[str] = "token"
    TOLL: Final[str] = "toll"
    TONALITY: Final[str] = "tonality"
    TOPIC: Final[str] = "topic"
    TORNADO: Final[str] = "tornado"
    TOUCH_APP: Final[str] = "touch_app"
    TOUR: Final[str] = "tour"
    TOYS: Final[str] = "toys"
    TRACK_CHANGES: Final[str] = "track_changes"
    TRAFFIC: Final[str] = "traffic"
    TRAIN: Final[str] = "train"
    TRAM: Final[str] = "tram"
    TRANSCRIBE: Final[str] = "transcribe"
    TRANSFER_WITHIN_A_STATION: Final[str] = "transfer_within_a_station"
    TRANSFORM: Final[str] = "transform"
    TRANSGENDER: Final[str] = "transgender"
    TRANSIT_ENTEREXIT: Final[str] = "transit_enterexit"
    TRANSLATE: Final[str] = "translate"
    TRAVEL_EXPLORE: Final[str] = "travel_explore"
    TRENDING_DOWN: Final[str] = "trending_down"
    TRENDING_FLAT: Final[str] = "trending_flat"
    TRENDING_NEUTRAL: Final[str] = "trending_neutral"
    TRENDING_UP: Final[str] = "trending_up"
    TRIP_ORIGIN: Final[str] = "trip_origin"
    TROLLEY: Final[str] = "trolley"
    TROUBLESHOOT: Final[str] = "troubleshoot"
    TRY: Final[str] = "try"
    TSUNAMI: Final[str] = "tsunami"
    TTY: Final[str] = "tty"
    TUNE: Final[str] = "tune"
    TUNGSTEN: Final[str] = "tungsten"
    TURN_LEFT: Final[str] = "turn_left"
    TURN_RIGHT: Final[str] = "turn_right"
    TURN_SHARP_LEFT: Final[str] = "turn_sharp_left"
    TURN_SHARP_RIGHT: Final[str] = "turn_sharp_right"
    TURN_SLIGHT_LEFT: Final[str] = "turn_slight_left"
    TURN_SLIGHT_RIGHT: Final[str] = "turn_slight_right"
    TURNED_IN: Final[str] = "turned_in"
    TURNED_IN_NOT: Final[str] = "turned_in_not"
    TV: Final[str] = "tv"
    TV_OFF: Final[str] = "tv_off"
    TWO_WHEELER: Final[str] = "two_wheeler"
    TYPE_SPECIMEN: Final[str] = "type_specimen"
    U_TURN_LEFT: Final[str] = "u_turn_left"
    U_TURN_RIGHT: Final[str] = "u_turn_right"
    UMBRELLA: Final[str] = "umbrella"
    UNARCHIVE: Final[str] = "unarchive"
    UNDO: Final[str] = "undo"
    UNFOLD_LESS: Final[str] = "unfold_less"
    UNFOLD_LESS_DOUBLE: Final[str] = "unfold_less_double"
    UNFOLD_MORE: Final[str] = "unfold_more"
    UNFOLD_MORE_DOUBLE: Final[str] = "unfold_more_double"
    UNPUBLISHED: Final[str] = "unpublished"
    UNSUBSCRIBE: Final[str] = "unsubscribe"
    UPCOMING: Final[str] = "upcoming"
    UPDATE: Final[str] = "update"
    UPDATE_DISABLED: Final[str] = "update_disabled"
    UPGRADE: Final[str] = "upgrade"
    UPLOAD: Final[str] = "upload"
    UPLOAD_FILE: Final[str] = "upload_file"
    USB: Final[str] = "usb"
    USB_OFF: Final[str] = "usb_off"
    VACCINES: Final[str] = "vaccines"
    VAPE_FREE: Final[str] = "vape_free"
    VAPING_ROOMS: Final[str] = "vaping_rooms"
    VERIFIED: Final[str] = "verified"
    VERIFIED_USER: Final[str] = "verified_user"
    VERTICAL_ALIGN_BOTTOM: Final[str] = "vertical_align_bottom"
    VERTICAL_ALIGN_CENTER: Final[str] = "vertical_align_center"
    VERTICAL_ALIGN_TOP: Final[str] = "vertical_align_top"
    VERTICAL_DISTRIBUTE: Final[str] = "vertical_distribute"
    VERTICAL_SHADES: Final[str] = "vertical_shades"
    VERTICAL_SHADES_CLOSED: Final[str] = "vertical_shades_closed"
    VERTICAL_SPLIT: Final[str] = "vertical_split"
    VIBRATION: Final[str] = "vibration"
    VIDEO_CALL: Final[str] = "video_call"
    VIDEO_CAMERA_BACK: Final[str] = "video_camera_back"
    VIDEO_CAMERA_FRONT: Final[str] = "video_camera_front"
    VIDEO_CHAT: Final[str] = "video_chat"
    VIDEO_COLLECTION: Final[str] = "video_collection"
    VIDEO_FILE: Final[str] = "video_file"
    VIDEO_LABEL: Final[str] = "video_label"
    VIDEO_LIBRARY: Final[str] = "video_library"
    VIDEO_SETTINGS: Final[str] = "video_settings"
    VIDEO_STABLE: Final[str] = "video_stable"
    VIDEOCAM: Final[str] = "videocam"
    VIDEOCAM_OFF: Final[str] = "videocam_off"
    VIDEOGAME_ASSET: Final[str] = "videogame_asset"
    VIDEOGAME_ASSET_OFF: Final[str] = "videogame_asset_off"
    VIEW_AGENDA: Final[str] = "view_agenda"
    VIEW_ARRAY: Final[str] = "view_array"
    VIEW_CAROUSEL: Final[str] = "view_carousel"
    VIEW_COLUMN: Final[str] = "view_column"
    VIEW_COMFORTABLE: Final[str] = "view_comfortable"
    VIEW_COMFY: Final[str] = "view_comfy"
    VIEW_COMFY_ALT: Final[str] = "view_comfy_alt"
    VIEW_COMPACT: Final[str] = "view_compact"
    VIEW_COMPACT_ALT: Final[str] = "view_compact_alt"
    VIEW_COZY: Final[str] = "view_cozy"
    VIEW_DAY: Final[str] = "view_day"
    VIEW_HEADLINE: Final[str] = "view_headline"
    VIEW_IN_AR: Final[str] = "view_in_ar"
    VIEW_KANBAN: Final[str] = "view_kanban"
    VIEW_LIST: Final[str] = "view_list"
    VIEW_MODULE: Final[str] = "view_module"
    VIEW_QUILT: Final[str] = "view_quilt"
    VIEW_SIDEBAR: Final[str] = "view_sidebar"
    VIEW_STREAM: Final[str] = "view_stream"
    VIEW_TIMELINE: Final[str] = "view_timeline"
    VIEW_WEEK: Final[str] = "view_week"
    VIGNETTE: Final[str] = "vignette"
    VILLA: Final[str] = "villa"
    VISIBILITY: Final[str] = "visibility"
    VISIBILITY_OFF: Final[str] = "visibility_off"
    VOICE_CHAT: Final[str] = "voice_chat"
    VOICE_OVER_OFF: Final[str] = "voice_over_off"
    VOICEMAIL: Final[str] = "voicemail"
    VOLCANO: Final[str] = "volcano"
    VOLUME_DOWN: Final[str] = "volume_down"
    VOLUME_DOWN_ALT: Final[str] = "volume_down_alt"
    VOLUME_MUTE: Final[str] = "volume_mute"
    VOLUME_OFF: Final[str] = "volume_off"
    VOLUME_UP: Final[str] = "volume_up"
    VOLUNTEER_ACTIVISM: Final[str] = "volunteer_activism"
    VPN_KEY: Final[str] = "vpn_key"
    VPN_KEY_OFF: Final[str] = "vpn_key_off"
    VPN_LOCK: Final[str] = "vpn_lock"
    VRPANO: Final[str] = "vrpano"
    WALLET: Final[str] = "wallet"
    WALLET_GIFTCARD: Final[str] = "wallet_giftcard"
    WALLET_MEMBERSHIP: Final[str] = "wallet_membership"
    WALLET_TRAVEL: Final[str] = "wallet_travel"
    WALLPAPER: Final[str] = "wallpaper"
    WAREHOUSE: Final[str] = "warehouse"
    WARNING: Final[str] = "warning"
    WARNING_AMBER: Final[str] = "warning_amber"
    WASH: Final[str] = "wash"
    WATCH: Final[str] = "watch"
    WATCH_LATER: Final[str] = "watch_later"
    WATCH_OFF: Final[str] = "watch_off"
    WATER: Final[str] = "water"
    WATER_DAMAGE: Final[str] = "water_damage"
    WATER_DROP: Final[str] = "water_drop"
    WATERFALL_CHART: Final[str] = "waterfall_chart"
    WAVES: Final[str] = "waves"
    WAVING_HAND: Final[str] = "waving_hand"
    WB_AUTO: Final[str] = "wb_auto"
    WB_CLOUDY: Final[str] = "wb_cloudy"
    WB_INCANDESCENT: Final[str] = "wb_incandescent"
    WB_IRIDESCENT: Final[str] = "wb_iridescent"
    WB_SHADE: Final[str] = "wb_shade"
    WB_SUNNY: Final[str] = "wb_sunny"
    WB_TWIGHLIGHT: Final[str] = "wb_twighlight"
    WB_TWILIGHT: Final[str] = "wb_twilight"
    WC: Final[str] = "wc"
    WEB: Final[str] = "web"
    WEB_ASSET: Final[str] = "web_asset"
    WEB_ASSET_OFF: Final[str] = "web_asset_off"
    WEB_STORIES: Final[str] = "web_stories"
    WEBHOOK: Final[str] = "webhook"
    WECHAT: Final[str] = "wechat"
    WEEKEND: Final[str] = "weekend"
    WEST: Final[str] = "west"
    WHATSHOT: Final[str] = "whatshot"
    WHEELCHAIR_PICKUP: Final[str] = "wheelchair_pickup"
    WHERE_TO_VOTE: Final[str] = "where_to_vote"
    WIDGETS: Final[str] = "widgets"
    WIDTH_FULL: Final[str] = "width_full"
    WIDTH_NORMAL: Final[str] = "width_normal"
    WIDTH_WIDE: Final[str] = "width_wide"
    WIFI: Final[str] = "wifi"
    WIFI_1_BAR: Final[str] = "wifi_1_bar"
    WIFI_2_BAR: Final[str] = "wifi_2_bar"
    WIFI_CALLING: Final[str] = "wifi_calling"
    WIFI_CALLING_3: Final[str] = "wifi_calling_3"
    WIFI_CHANNEL: Final[str] = "wifi_channel"
    WIFI_FIND: Final[str] = "wifi_find"
    WIFI_LOCK: Final[str] = "wifi_lock"
    WIFI_OFF: Final[str] = "wifi_off"
    WIFI_PASSWORD: Final[str] = "wifi_password"
    WIFI_PROTECTED_SETUP: Final[str] = "wifi_protected_setup"
    WIFI_TETHERING: Final[str] = "wifi_tethering"
    WIFI_TETHERING_ERROR: Final[str] = "wifi_tethering_error"
    WIFI_TETHERING_ERROR_ROUNDED: Final[str] = "wifi_tethering_error_rounded"
    WIFI_TETHERING_OFF: Final[str] = "wifi_tethering_off"
    WIND_POWER: Final[str] = "wind_power"
    WINDOW: Final[str] = "window"
    WINE_BAR: Final[str] = "wine_bar"
    WOMAN: Final[str] = "woman"
    WOMAN_2: Final[str] = "woman_2"
    WOO_COMMERCE: Final[str] = "woo_commerce"
    WORDPRESS: Final[str] = "wordpress"
    WORK: Final[str] = "work"
    WORK_HISTORY: Final[str] = "work_history"
    WORK_OFF: Final[str] = "work_off"
    WORK_OUTLINE: Final[str] = "work_outline"
    WORKSPACE_PREMIUM: Final[str] = "workspace_premium"
    WORKSPACES: Final[str] = "workspaces"
    WORKSPACES_FILLED: Final[str] = "workspaces_filled"
    WORKSPACES_OUTLINE: Final[str] = "workspaces_outline"
    WRAP_TEXT: Final[str] = "wrap_text"
    WRONG_LOCATION: Final[str] = "wrong_location"
    WYSIWYG: Final[str] = "wysiwyg"
    YARD: Final[str] = "yard"
    YOUTUBE_SEARCHED_FOR: Final[str] = "youtube_searched_for"
    ZOOM_IN: Final[str] = "zoom_in"
    ZOOM_IN_MAP: Final[str] = "zoom_in_map"
    ZOOM_OUT: Final[str] = "zoom_out"
    ZOOM_OUT_MAP: Final[str] = "zoom_out_map"

    # Common aliases for better IDE experience
    USERS = PEOPLE
    USER = PERSON
    DOCUMENTS = DESCRIPTION
    FILES = INSERT_DRIVE_FILE
    FOLDERS = FOLDER
    MESSAGES = MESSAGE
    EMAILS = EMAIL
    TASKS = QUEUE
    AGENTS = SMART_TOY
    AI = SMART_TOY


# IDE-friendly icon categories for easy discovery
class IconCategories:
    """Categorized icon collections for easy discovery."""

    NAVIGATION: Dict[str, str] = {
        'add_home': Icons.ADD_HOME,
        'add_home_work': Icons.ADD_HOME_WORK,
        'add_home_work': Icons.ADD_HOME_WORK,
        'add_to_home_screen': Icons.ADD_TO_HOME_SCREEN,
        'app_settings_alt': Icons.APP_SETTINGS_ALT,
        'apps': Icons.APPS,
        'apps': Icons.APPS,
        'apps_outage': Icons.APPS_OUTAGE,
        'apps_outage': Icons.APPS_OUTAGE,
        'arrow_back': Icons.ARROW_BACK,
        'arrow_back': Icons.ARROW_BACK,
        'arrow_back_ios': Icons.ARROW_BACK_IOS,
        'arrow_back_ios': Icons.ARROW_BACK_IOS,
        'arrow_back_ios_new': Icons.ARROW_BACK_IOS_NEW,
        'arrow_back_ios_new': Icons.ARROW_BACK_IOS_NEW,
        'arrow_circle_down': Icons.ARROW_CIRCLE_DOWN,
        'arrow_circle_left': Icons.ARROW_CIRCLE_LEFT,
        'arrow_circle_right': Icons.ARROW_CIRCLE_RIGHT,
        'arrow_circle_up': Icons.ARROW_CIRCLE_UP,
        'arrow_downward': Icons.ARROW_DOWNWARD,
    }

    USERS: Dict[str, str] = {
        'account_balance': Icons.ACCOUNT_BALANCE,
        'account_balance_wallet': Icons.ACCOUNT_BALANCE_WALLET,
        'account_box': Icons.ACCOUNT_BOX,
        'account_circle': Icons.ACCOUNT_CIRCLE,
        'account_tree': Icons.ACCOUNT_TREE,
        'broadcast_on_personal': Icons.BROADCAST_ON_PERSONAL,
        'emoji_people': Icons.EMOJI_PEOPLE,
        'face': Icons.FACE,
        'face_2': Icons.FACE_2,
        'face_3': Icons.FACE_3,
        'face_4': Icons.FACE_4,
        'face_5': Icons.FACE_5,
        'face_6': Icons.FACE_6,
        'face_retouching_natural': Icons.FACE_RETOUCHING_NATURAL,
        'face_retouching_off': Icons.FACE_RETOUCHING_OFF,
        'facebook': Icons.FACEBOOK,
        'group': Icons.GROUP,
        'group_add': Icons.GROUP_ADD,
        'group_off': Icons.GROUP_OFF,
        'group_remove': Icons.GROUP_REMOVE,
    }

    DOCUMENTS: Dict[str, str] = {
        'article': Icons.ARTICLE,
        'attach_file': Icons.ATTACH_FILE,
        'audio_file': Icons.AUDIO_FILE,
        'contact_page': Icons.CONTACT_PAGE,
        'create_new_folder': Icons.CREATE_NEW_FOLDER,
        'description': Icons.DESCRIPTION,
        'document_scanner': Icons.DOCUMENT_SCANNER,
        'drive_file_move': Icons.DRIVE_FILE_MOVE,
        'drive_file_move_outline': Icons.DRIVE_FILE_MOVE_OUTLINE,
        'drive_file_move_rtl': Icons.DRIVE_FILE_MOVE_RTL,
        'drive_file_rename_outline': Icons.DRIVE_FILE_RENAME_OUTLINE,
        'drive_folder_upload': Icons.DRIVE_FOLDER_UPLOAD,
        'edit_document': Icons.EDIT_DOCUMENT,
        'edit_note': Icons.EDIT_NOTE,
        'event_note': Icons.EVENT_NOTE,
        'file_copy': Icons.FILE_COPY,
        'file_download': Icons.FILE_DOWNLOAD,
        'file_download_done': Icons.FILE_DOWNLOAD_DONE,
        'file_download_off': Icons.FILE_DOWNLOAD_OFF,
        'file_open': Icons.FILE_OPEN,
    }

    COMMUNICATION: Dict[str, str] = {
        '3p': Icons._3P,
        'add_call': Icons.ADD_CALL,
        'add_comment': Icons.ADD_COMMENT,
        'add_ic_call': Icons.ADD_IC_CALL,
        'add_ic_call': Icons.ADD_IC_CALL,
        'alternate_email': Icons.ALTERNATE_EMAIL,
        'alternate_email': Icons.ALTERNATE_EMAIL,
        'app_registration': Icons.APP_REGISTRATION,
        'attach_email': Icons.ATTACH_EMAIL,
        'business': Icons.BUSINESS,
        'call': Icons.CALL,
        'call': Icons.CALL,
        'call_end': Icons.CALL_END,
        'call_end': Icons.CALL_END,
        'call_made': Icons.CALL_MADE,
        'call_made': Icons.CALL_MADE,
        'call_merge': Icons.CALL_MERGE,
        'call_merge': Icons.CALL_MERGE,
        'call_missed': Icons.CALL_MISSED,
        'call_missed': Icons.CALL_MISSED,
    }

    AI_AUTOMATION: Dict[str, str] = {
        'auto_awesome': Icons.AUTO_AWESOME,
        'auto_awesome_mosaic': Icons.AUTO_AWESOME_MOSAIC,
        'auto_awesome_motion': Icons.AUTO_AWESOME_MOTION,
        'auto_delete': Icons.AUTO_DELETE,
        'auto_fix_high': Icons.AUTO_FIX_HIGH,
        'auto_fix_normal': Icons.AUTO_FIX_NORMAL,
        'auto_fix_off': Icons.AUTO_FIX_OFF,
        'auto_graph': Icons.AUTO_GRAPH,
        'auto_mode': Icons.AUTO_MODE,
        'auto_stories': Icons.AUTO_STORIES,
        'autofps_select': Icons.AUTOFPS_SELECT,
        'autorenew': Icons.AUTORENEW,
        'brightness_auto': Icons.BRIGHTNESS_AUTO,
        'cloud_sync': Icons.CLOUD_SYNC,
        'event_repeat': Icons.EVENT_REPEAT,
        'fiber_smart_record': Icons.FIBER_SMART_RECORD,
        'flash_auto': Icons.FLASH_AUTO,
        'hdr_auto': Icons.HDR_AUTO,
        'hdr_auto_select': Icons.HDR_AUTO_SELECT,
        'memory': Icons.MEMORY,
    }

    ACTIONS: Dict[str, str] = {
        'add': Icons.ADD,
        'add_a_photo': Icons.ADD_A_PHOTO,
        'add_alarm': Icons.ADD_ALARM,
        'add_alert': Icons.ADD_ALERT,
        'add_box': Icons.ADD_BOX,
        'add_business': Icons.ADD_BUSINESS,
        'add_card': Icons.ADD_CARD,
        'add_chart': Icons.ADD_CHART,
        'add_circle': Icons.ADD_CIRCLE,
        'add_circle_outline': Icons.ADD_CIRCLE_OUTLINE,
        'add_link': Icons.ADD_LINK,
        'add_location': Icons.ADD_LOCATION,
        'add_location_alt': Icons.ADD_LOCATION_ALT,
        'add_moderator': Icons.ADD_MODERATOR,
        'add_photo_alternate': Icons.ADD_PHOTO_ALTERNATE,
        'add_reaction': Icons.ADD_REACTION,
        'add_road': Icons.ADD_ROAD,
        'add_shopping_cart': Icons.ADD_SHOPPING_CART,
        'add_task': Icons.ADD_TASK,
        'add_to_drive': Icons.ADD_TO_DRIVE,
    }

    STATUS: Dict[str, str] = {
        'check': Icons.CHECK,
        'check_box': Icons.CHECK_BOX,
        'check_box_outline_blank': Icons.CHECK_BOX_OUTLINE_BLANK,
        'check_circle': Icons.CHECK_CIRCLE,
        'check_circle_outline': Icons.CHECK_CIRCLE_OUTLINE,
        'checklist': Icons.CHECKLIST,
        'checklist_rtl': Icons.CHECKLIST_RTL,
        'checkroom': Icons.CHECKROOM,
        'error': Icons.ERROR,
        'error_outline': Icons.ERROR_OUTLINE,
        'escalator_warning': Icons.ESCALATOR_WARNING,
        'fact_check': Icons.FACT_CHECK,
        'indeterminate_check_box': Icons.INDETERMINATE_CHECK_BOX,
        'info': Icons.INFO,
        'info_outline': Icons.INFO_OUTLINE,
        'medical_information': Icons.MEDICAL_INFORMATION,
        'nearby_error': Icons.NEARBY_ERROR,
        'network_check': Icons.NETWORK_CHECK,
        'pending': Icons.PENDING,
        'pending_actions': Icons.PENDING_ACTIONS,
    }

    MEDIA: Dict[str, str] = {
        'assistant_photo': Icons.ASSISTANT_PHOTO,
        'audiotrack': Icons.AUDIOTRACK,
        'bluetooth_audio': Icons.BLUETOOTH_AUDIO,
        'broken_image': Icons.BROKEN_IMAGE,
        'camera': Icons.CAMERA,
        'camera_alt': Icons.CAMERA_ALT,
        'camera_enhance': Icons.CAMERA_ENHANCE,
        'camera_front': Icons.CAMERA_FRONT,
        'camera_indoor': Icons.CAMERA_INDOOR,
        'camera_outdoor': Icons.CAMERA_OUTDOOR,
        'camera_rear': Icons.CAMERA_REAR,
        'camera_roll': Icons.CAMERA_ROLL,
        'cameraswitch': Icons.CAMERASWITCH,
        'control_camera': Icons.CONTROL_CAMERA,
        'dynamic_feed': Icons.DYNAMIC_FEED,
        'dynamic_form': Icons.DYNAMIC_FORM,
        'enhance_photo_translate': Icons.ENHANCE_PHOTO_TRANSLATE,
        'featured_video': Icons.FEATURED_VIDEO,
        'flip_camera_android': Icons.FLIP_CAMERA_ANDROID,
        'flip_camera_ios': Icons.FLIP_CAMERA_IOS,
    }

    SETTINGS: Dict[str, str] = {
        'admin_panel_settings': Icons.ADMIN_PANEL_SETTINGS,
        'app_settings_alt': Icons.APP_SETTINGS_ALT,
        'build': Icons.BUILD,
        'build_circle': Icons.BUILD_CIRCLE,
        'construction': Icons.CONSTRUCTION,
        'power_settings_new': Icons.POWER_SETTINGS_NEW,
        'query_builder': Icons.QUERY_BUILDER,
        'settings': Icons.SETTINGS,
        'settings_accessibility': Icons.SETTINGS_ACCESSIBILITY,
        'settings_applications': Icons.SETTINGS_APPLICATIONS,
        'settings_backup_restore': Icons.SETTINGS_BACKUP_RESTORE,
        'settings_bluetooth': Icons.SETTINGS_BLUETOOTH,
        'settings_brightness': Icons.SETTINGS_BRIGHTNESS,
        'settings_cell': Icons.SETTINGS_CELL,
        'settings_ethernet': Icons.SETTINGS_ETHERNET,
        'settings_input_antenna': Icons.SETTINGS_INPUT_ANTENNA,
        'settings_input_component': Icons.SETTINGS_INPUT_COMPONENT,
        'settings_input_composite': Icons.SETTINGS_INPUT_COMPOSITE,
        'settings_input_hdmi': Icons.SETTINGS_INPUT_HDMI,
        'settings_overscan': Icons.SETTINGS_OVERSCAN,
    }

    COMMERCE: Dict[str, str] = {
        'attach_money': Icons.ATTACH_MONEY,
        'local_convenience_store': Icons.LOCAL_CONVENIENCE_STORE,
        'local_grocery_store': Icons.LOCAL_GROCERY_STORE,
        'money': Icons.MONEY,
        'money_off': Icons.MONEY_OFF,
        'money_off_csred': Icons.MONEY_OFF_CSRED,
        'payment': Icons.PAYMENT,
        'payments': Icons.PAYMENTS,
        'price_change': Icons.PRICE_CHANGE,
        'restore': Icons.RESTORE,
        'restore_from_trash': Icons.RESTORE_FROM_TRASH,
        'sell': Icons.SELL,
        'shopping_bag': Icons.SHOPPING_BAG,
        'shopping_basket': Icons.SHOPPING_BASKET,
        'shopping_cart': Icons.SHOPPING_CART,
        'store': Icons.STORE,
        'store_mall_directory': Icons.STORE_MALL_DIRECTORY,
        'storefront': Icons.STOREFRONT,
    }

    TRAVEL: Dict[str, str] = {
        'car_crash': Icons.CAR_CRASH,
        'car_rental': Icons.CAR_RENTAL,
        'car_repair': Icons.CAR_REPAIR,
        'card_giftcard': Icons.CARD_GIFTCARD,
        'card_membership': Icons.CARD_MEMBERSHIP,
        'card_travel': Icons.CARD_TRAVEL,
        'carpenter': Icons.CARPENTER,
        'child_care': Icons.CHILD_CARE,
        'directions': Icons.DIRECTIONS,
        'directions_bike': Icons.DIRECTIONS_BIKE,
        'directions_boat': Icons.DIRECTIONS_BOAT,
        'directions_boat_filled': Icons.DIRECTIONS_BOAT_FILLED,
        'directions_bus': Icons.DIRECTIONS_BUS,
        'directions_bus_filled': Icons.DIRECTIONS_BUS_FILLED,
        'directions_car': Icons.DIRECTIONS_CAR,
        'directions_car_filled': Icons.DIRECTIONS_CAR_FILLED,
        'directions_ferry': Icons.DIRECTIONS_FERRY,
        'directions_off': Icons.DIRECTIONS_OFF,
        'directions_railway': Icons.DIRECTIONS_RAILWAY,
        'directions_railway_filled': Icons.DIRECTIONS_RAILWAY_FILLED,
    }

    SOCIAL: Dict[str, str] = {
        '18_up_rating': Icons._18_UP_RATING,
        '6_ft_apart': Icons._6_FT_APART,
        'add_moderator': Icons.ADD_MODERATOR,
        'add_reaction': Icons.ADD_REACTION,
        'architecture': Icons.ARCHITECTURE,
        'assist_walker': Icons.ASSIST_WALKER,
        'back_hand': Icons.BACK_HAND,
        'blind': Icons.BLIND,
        'bookmark': Icons.BOOKMARK,
        'bookmark_border': Icons.BOOKMARK_BORDER,
        'bookmark_outline': Icons.BOOKMARK_OUTLINE,
        'bookmarks': Icons.BOOKMARKS,
        'boy': Icons.BOY,
        'cake': Icons.CAKE,
        'catching_pokemon': Icons.CATCHING_POKEMON,
        'clean_hands': Icons.CLEAN_HANDS,
        'co2': Icons.CO2,
        'collections_bookmark': Icons.COLLECTIONS_BOOKMARK,
        'compost': Icons.COMPOST,
        'connect_without_contact': Icons.CONNECT_WITHOUT_CONTACT,
    }

    DEVICE: Dict[str, str] = {
        '1x_mobiledata': Icons._1X_MOBILEDATA,
        '30fps': Icons._30FPS,
        '3g_mobiledata': Icons._3G_MOBILEDATA,
        '4g_mobiledata': Icons._4G_MOBILEDATA,
        '4g_plus_mobiledata': Icons._4G_PLUS_MOBILEDATA,
        '60fps': Icons._60FPS,
        'access_alarm': Icons.ACCESS_ALARM,
        'access_alarms': Icons.ACCESS_ALARMS,
        'access_time': Icons.ACCESS_TIME,
        'access_time_filled': Icons.ACCESS_TIME_FILLED,
        'ad_units': Icons.AD_UNITS,
        'add_alarm': Icons.ADD_ALARM,
        'add_to_home_screen': Icons.ADD_TO_HOME_SCREEN,
        'air': Icons.AIR,
        'airplane_ticket': Icons.AIRPLANE_TICKET,
        'airplanemode_active': Icons.AIRPLANEMODE_ACTIVE,
        'airplanemode_inactive': Icons.AIRPLANEMODE_INACTIVE,
        'aod': Icons.AOD,
        'battery_0_bar': Icons.BATTERY_0_BAR,
        'battery_1_bar': Icons.BATTERY_1_BAR,
    }

    EDITOR: Dict[str, str] = {
        'add_chart': Icons.ADD_CHART,
        'add_comment': Icons.ADD_COMMENT,
        'align_horizontal_center': Icons.ALIGN_HORIZONTAL_CENTER,
        'align_horizontal_center': Icons.ALIGN_HORIZONTAL_CENTER,
        'align_horizontal_left': Icons.ALIGN_HORIZONTAL_LEFT,
        'align_horizontal_left': Icons.ALIGN_HORIZONTAL_LEFT,
        'align_horizontal_right': Icons.ALIGN_HORIZONTAL_RIGHT,
        'align_horizontal_right': Icons.ALIGN_HORIZONTAL_RIGHT,
        'align_vertical_bottom': Icons.ALIGN_VERTICAL_BOTTOM,
        'align_vertical_bottom': Icons.ALIGN_VERTICAL_BOTTOM,
        'align_vertical_center': Icons.ALIGN_VERTICAL_CENTER,
        'align_vertical_center': Icons.ALIGN_VERTICAL_CENTER,
        'align_vertical_top': Icons.ALIGN_VERTICAL_TOP,
        'align_vertical_top': Icons.ALIGN_VERTICAL_TOP,
        'area_chart': Icons.AREA_CHART,
        'attach_file': Icons.ATTACH_FILE,
        'attach_money': Icons.ATTACH_MONEY,
        'auto_graph': Icons.AUTO_GRAPH,
        'bar_chart': Icons.BAR_CHART,
        'border_all': Icons.BORDER_ALL,
    }

    MAPS: Dict[str, str] = {
        '360': Icons._360,
        'add_business': Icons.ADD_BUSINESS,
        'add_location': Icons.ADD_LOCATION,
        'add_location_alt': Icons.ADD_LOCATION_ALT,
        'add_road': Icons.ADD_ROAD,
        'agriculture': Icons.AGRICULTURE,
        'airline_stops': Icons.AIRLINE_STOPS,
        'airlines': Icons.AIRLINES,
        'alt_route': Icons.ALT_ROUTE,
        'assistant_navigation': Icons.ASSISTANT_NAVIGATION,
        'atm': Icons.ATM,
        'attractions': Icons.ATTRACTIONS,
        'badge': Icons.BADGE,
        'bakery_dining': Icons.BAKERY_DINING,
        'beenhere': Icons.BEENHERE,
        'bike_scooter': Icons.BIKE_SCOOTER,
        'breakfast_dining': Icons.BREAKFAST_DINING,
        'brunch_dining': Icons.BRUNCH_DINING,
        'bus_alert': Icons.BUS_ALERT,
        'car_crash': Icons.CAR_CRASH,
    }

    NOTIFICATION: Dict[str, str] = {
        'account_tree': Icons.ACCOUNT_TREE,
        'adb': Icons.ADB,
        'airline_seat_flat': Icons.AIRLINE_SEAT_FLAT,
        'airline_seat_flat_angled': Icons.AIRLINE_SEAT_FLAT_ANGLED,
        'airline_seat_individual_suite': Icons.AIRLINE_SEAT_INDIVIDUAL_SUITE,
        'airline_seat_legroom_extra': Icons.AIRLINE_SEAT_LEGROOM_EXTRA,
        'airline_seat_legroom_normal': Icons.AIRLINE_SEAT_LEGROOM_NORMAL,
        'airline_seat_legroom_reduced': Icons.AIRLINE_SEAT_LEGROOM_REDUCED,
        'airline_seat_recline_extra': Icons.AIRLINE_SEAT_RECLINE_EXTRA,
        'airline_seat_recline_normal': Icons.AIRLINE_SEAT_RECLINE_NORMAL,
        'announcement': Icons.ANNOUNCEMENT,
        'battery_alert': Icons.BATTERY_ALERT,
        'bluetooth_audio': Icons.BLUETOOTH_AUDIO,
        'bus_alert': Icons.BUS_ALERT,
        'circle_notifications': Icons.CIRCLE_NOTIFICATIONS,
        'confirmation_number': Icons.CONFIRMATION_NUMBER,
        'crisis_alert': Icons.CRISIS_ALERT,
        'directions_off': Icons.DIRECTIONS_OFF,
        'disc_full': Icons.DISC_FULL,
        'do_disturb': Icons.DO_DISTURB,
    }

    CONTENT: Dict[str, str] = {
        '30fps_select': Icons._30FPS_SELECT,
        '60fps_select': Icons._60FPS_SELECT,
        'add': Icons.ADD,
        'add_box': Icons.ADD_BOX,
        'add_circle': Icons.ADD_CIRCLE,
        'add_circle_outline': Icons.ADD_CIRCLE_OUTLINE,
        'add_link': Icons.ADD_LINK,
        'app_shortcut': Icons.APP_SHORTCUT,
        'archive': Icons.ARCHIVE,
        'attribution': Icons.ATTRIBUTION,
        'backspace': Icons.BACKSPACE,
        'ballot': Icons.BALLOT,
        'biotech': Icons.BIOTECH,
        'block': Icons.BLOCK,
        'bolt': Icons.BOLT,
        'calculate': Icons.CALCULATE,
        'change_circle': Icons.CHANGE_CIRCLE,
        'clear': Icons.CLEAR,
        'content_copy': Icons.CONTENT_COPY,
        'content_copy': Icons.CONTENT_COPY,
    }

    HARDWARE: Dict[str, str] = {
        'adf_scanner': Icons.ADF_SCANNER,
        'battery_0_bar': Icons.BATTERY_0_BAR,
        'battery_1_bar': Icons.BATTERY_1_BAR,
        'battery_2_bar': Icons.BATTERY_2_BAR,
        'battery_3_bar': Icons.BATTERY_3_BAR,
        'battery_4_bar': Icons.BATTERY_4_BAR,
        'battery_5_bar': Icons.BATTERY_5_BAR,
        'battery_6_bar': Icons.BATTERY_6_BAR,
        'battery_charging_full': Icons.BATTERY_CHARGING_FULL,
        'battery_full': Icons.BATTERY_FULL,
        'battery_std': Icons.BATTERY_STD,
        'battery_unknown': Icons.BATTERY_UNKNOWN,
        'bluetooth': Icons.BLUETOOTH,
        'bluetooth_connected': Icons.BLUETOOTH_CONNECTED,
        'bluetooth_disabled': Icons.BLUETOOTH_DISABLED,
        'bluetooth_drive': Icons.BLUETOOTH_DRIVE,
        'bluetooth_searching': Icons.BLUETOOTH_SEARCHING,
        'browser_not_supported': Icons.BROWSER_NOT_SUPPORTED,
        'browser_updated': Icons.BROWSER_UPDATED,
        'cast': Icons.CAST,
    }

    IMAGE: Dict[str, str] = {
        '10mp': Icons._10MP,
        '11mp': Icons._11MP,
        '12mp': Icons._12MP,
        '13mp': Icons._13MP,
        '14mp': Icons._14MP,
        '15mp': Icons._15MP,
        '16mp': Icons._16MP,
        '17mp': Icons._17MP,
        '18mp': Icons._18MP,
        '19mp': Icons._19MP,
        '20mp': Icons._20MP,
        '21mp': Icons._21MP,
        '22mp': Icons._22MP,
        '23mp': Icons._23MP,
        '24mp': Icons._24MP,
        '2mp': Icons._2MP,
        '30fps_select': Icons._30FPS_SELECT,
        '3mp': Icons._3MP,
        '4mp': Icons._4MP,
        '5mp': Icons._5MP,
    }

    AV: Dict[str, str] = {
        '10k': Icons._10K,
        '1k': Icons._1K,
        '1k_plus': Icons._1K_PLUS,
        '2k': Icons._2K,
        '2k_plus': Icons._2K_PLUS,
        '3k': Icons._3K,
        '3k_plus': Icons._3K_PLUS,
        '4k': Icons._4K,
        '4k_plus': Icons._4K_PLUS,
        '5g': Icons._5G,
        '5k': Icons._5K,
        '5k_plus': Icons._5K_PLUS,
        '6k': Icons._6K,
        '6k_plus': Icons._6K_PLUS,
        '7k': Icons._7K,
        '7k_plus': Icons._7K_PLUS,
        '8k': Icons._8K,
        '8k_plus': Icons._8K_PLUS,
        '9k': Icons._9K,
        '9k_plus': Icons._9K_PLUS,
    }

    PLACES: Dict[str, str] = {
        'ac_unit': Icons.AC_UNIT,
        'airport_shuttle': Icons.AIRPORT_SHUTTLE,
        'all_inclusive': Icons.ALL_INCLUSIVE,
        'apartment': Icons.APARTMENT,
        'assured_workload': Icons.ASSURED_WORKLOAD,
        'baby_changing_station': Icons.BABY_CHANGING_STATION,
        'backpack': Icons.BACKPACK,
        'balcony': Icons.BALCONY,
        'bathtub': Icons.BATHTUB,
        'beach_access': Icons.BEACH_ACCESS,
        'bento': Icons.BENTO,
        'bungalow': Icons.BUNGALOW,
        'business_center': Icons.BUSINESS_CENTER,
        'cabin': Icons.CABIN,
        'carpenter': Icons.CARPENTER,
        'casino': Icons.CASINO,
        'chalet': Icons.CHALET,
        'charging_station': Icons.CHARGING_STATION,
        'checkroom': Icons.CHECKROOM,
        'child_care': Icons.CHILD_CARE,
    }

    FILE: Dict[str, str] = {
        'approval': Icons.APPROVAL,
        'archive': Icons.ARCHIVE,
        'attach_email': Icons.ATTACH_EMAIL,
        'attachment': Icons.ATTACHMENT,
        'attachment': Icons.ATTACHMENT,
        'cloud': Icons.CLOUD,
        'cloud_circle': Icons.CLOUD_CIRCLE,
        'cloud_done': Icons.CLOUD_DONE,
        'cloud_download': Icons.CLOUD_DOWNLOAD,
        'cloud_download': Icons.CLOUD_DOWNLOAD,
        'cloud_off': Icons.CLOUD_OFF,
        'cloud_queue': Icons.CLOUD_QUEUE,
        'cloud_sync': Icons.CLOUD_SYNC,
        'cloud_upload': Icons.CLOUD_UPLOAD,
        'cloud_upload': Icons.CLOUD_UPLOAD,
        'create_new_folder': Icons.CREATE_NEW_FOLDER,
        'difference': Icons.DIFFERENCE,
        'download': Icons.DOWNLOAD,
        'download': Icons.DOWNLOAD,
        'download_done': Icons.DOWNLOAD_DONE,
    }

    TOGGLE: Dict[str, str] = {
        '3d_rotation': Icons._3D_ROTATION,
        'airplanemode_off': Icons.AIRPLANEMODE_OFF,
        'airplanemode_on': Icons.AIRPLANEMODE_ON,
        'alarm_off': Icons.ALARM_OFF,
        'alarm_on': Icons.ALARM_ON,
        'animation': Icons.ANIMATION,
        'app_registration': Icons.APP_REGISTRATION,
        'assistant_direction': Icons.ASSISTANT_DIRECTION,
        'attractions': Icons.ATTRACTIONS,
        'attribution': Icons.ATTRIBUTION,
        'baby_changing_station': Icons.BABY_CHANGING_STATION,
        'balcony': Icons.BALCONY,
        'batch_prediction': Icons.BATCH_PREDICTION,
        'bedtime_off': Icons.BEDTIME_OFF,
        'blur_off': Icons.BLUR_OFF,
        'blur_on': Icons.BLUR_ON,
        'book_online': Icons.BOOK_ONLINE,
        'border_horizontal': Icons.BORDER_HORIZONTAL,
        'calendar_month': Icons.CALENDAR_MONTH,
        'calendar_view_month': Icons.CALENDAR_VIEW_MONTH,
    }

    OTHER: Dict[str, str] = {
        '10k': Icons._10K,
        '10mp': Icons._10MP,
        '11mp': Icons._11MP,
        '123': Icons._123,
        '12mp': Icons._12MP,
        '13mp': Icons._13MP,
        '14mp': Icons._14MP,
        '15mp': Icons._15MP,
        '16mp': Icons._16MP,
        '17mp': Icons._17MP,
        '18_up_rating': Icons._18_UP_RATING,
        '18mp': Icons._18MP,
        '19mp': Icons._19MP,
        '1k': Icons._1K,
        '1k_plus': Icons._1K_PLUS,
        '1x_mobiledata': Icons._1X_MOBILEDATA,
        '20mp': Icons._20MP,
        '21mp': Icons._21MP,
        '22mp': Icons._22MP,
        '23mp': Icons._23MP,
    }



# Validation function for IDE
def validate_icon_constant(icon_name: str) -> bool:
    """
    Validate that an icon constant exists.
    
    Args:
        icon_name: The icon name to validate
        
    Returns:
        True if the icon exists in Material Icons
    """
    from .icons import MaterialIcons
    return MaterialIcons.is_valid_icon(icon_name)


# Export commonly used icons for direct import
__all__ = [
    'Icons',
    'IconCategories',
    'validate_icon_constant',
]
